with Ada.Exceptions;

with Interfaces.C;

with GNAT.IO; use GNAT.IO;

with GNATCOM.Initialize; use GNATCOM.Initialize;
with GNATCOM.VARIANT; use GNATCOM.VARIANT;
with GNATCOM.Types; use GNATCOM.Types;
with GNATCOM.GUID;
with GNATCOM.Dispinterface; use GNATCOM.Dispinterface;
use GNATCOM;

procedure Mapi is
   pragma Linker_Options ("-lole32");
   pragma Linker_Options ("-loleaut32");

   Session    : Dispinterface_Type; -- MAPI.Session
   Outbox     : Dispinterface_Type; -- MAPI.Folder
   Messages   : Dispinterface_Type; -- MAPI.Messages
   Message    : Dispinterface_Type; -- MAPI.Message
   Recipients : Dispinterface_Type; -- MAPI.Recipients
   Recipient  : Dispinterface_Type; -- MAPI.Recipient

   Result     : GNATCOM.Types.Variant;

begin
   Put_Line ("-- Use MAPI interface");
   New_Line;

   Initialize_COM;

   Put_Line ("-- Create");
   Create (Session, "MAPI.Session", CLSCTX_INPROC_SERVER);

   Result := Invoke (Session, "Logon");

   Put_Line("User Name : " &
            To_Ada(Get (Session, "CurrentUser"), True));

   Put_Line("Create outbox object");
   Attach (Outbox, Get (Session, "Outbox"));

   Put_Line("Get Messages collection");
   Attach (Messages, Get (Outbox, "Messages"));
           
   Put_Line("Create new message to send");
   Attach (Message, Invoke (Messages, "Add"));

   Put_Line("Set subject");
   Put (Message, "Subject", To_VARIANT ("DispInterface Example"));

   Put_Line("Set body");
   Put (Message, "Text", To_VARIANT ("Cool tools for AdaPower.com!"));
 
   Put_Line("Create new recipient list");
   Attach (Recipients, Get (Message, "Recipients"));

   Put_Line("Create new recipient");
   Attach (Recipient, Get (Recipients, "Add"));

   Put_Line("Set Name");
   Put (Recipient, "Name", To_Variant("AdaCom@AdaPower.com"));

   Put_Line("Set Type");
   Put (Recipient, "Type", To_Variant(1)); -- Mapi_To

   Put_Line("Resolve new recipient");
   Result := Invoke (Recipient, "Resolve", (1 => VARIANT_TRUE)); -- Showdialog

   Put_Line("Update Message");
   Result := Invoke (Message, "Update");

   Put_Line("Send Message");
   Result := Invoke (Message, "Send");

   Put_Line("Logoff");
   Result := Invoke (Session, "Logoff");

   Uninitialize_COM;

   Put_Line ("-- Done");
   New_Line;

exception
   when E : others =>
      Put_Line (Ada.Exceptions.Exception_Name (E));
      Put_Line (Ada.Exceptions.Exception_Message(E));
      Uninitialize_COM;
end Mapi;
