with GNATCOM.Interface;

with GNATCOM.Errors;

package body IE.ISearchAssistantOC_Interface is

   procedure Initialize (This : in out ISearchAssistantOC_Type) is
   begin
      Set_IID (This, IID_ISearchAssistantOC);
   end Initialize;

   function Pointer (This : ISearchAssistantOC_Type)
     return Pointer_To_ISearchAssistantOC
   is
   begin
      return To_Pointer_To_ISearchAssistantOC (Address (This));
   end Pointer;

   procedure Attach (This    : in out ISearchAssistantOC_Type;
                     Pointer : in     Pointer_To_ISearchAssistantOC)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

   procedure AddNextMenuItem
     (This     : ISearchAssistantOC_Type;
      bstrText : GNATCOM.Types.BSTR;
      idItem   : Interfaces.C.long;
      Free     : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddNextMenuItem
         (Pointer (This),
          bstrText,
          idItem));

      if Free then
               GNATCOM.Interface.Free (bstrText);
      
      end if;

   end AddNextMenuItem;

   procedure SetDefaultSearchUrl
     (This    : ISearchAssistantOC_Type;
      bstrUrl : GNATCOM.Types.BSTR;
      Free    : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SetDefaultSearchUrl
         (Pointer (This),
          bstrUrl));

      if Free then
               GNATCOM.Interface.Free (bstrUrl);
      
      end if;

   end SetDefaultSearchUrl;

   procedure NavigateToDefaultSearch
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NavigateToDefaultSearch
         (Pointer (This)));

   end NavigateToDefaultSearch;

    function IsRestricted
     (This     : ISearchAssistantOC_Type;
      bstrGuid : GNATCOM.Types.BSTR;
      Free     : Boolean := True)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsRestricted
         (Pointer (This),
          bstrGuid,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (bstrGuid);
      
      end if;

      return RetVal;
   end IsRestricted;

    function Get_ShellFeaturesEnabled
     (This : ISearchAssistantOC_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ShellFeaturesEnabled
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ShellFeaturesEnabled;

    function Get_SearchAssistantDefault
     (This : ISearchAssistantOC_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SearchAssistantDefault
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SearchAssistantDefault;

    function Get_Searches
     (This : ISearchAssistantOC_Type)
     return Pointer_To_ISearches
   is
       RetVal : aliased Pointer_To_ISearches;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Searches
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Searches;

    function Get_InWebFolder
     (This : ISearchAssistantOC_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_InWebFolder
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_InWebFolder;

   procedure PutProperty
     (This       : ISearchAssistantOC_Type;
      bPerLocale : GNATCOM.Types.VARIANT_BOOL;
      bstrName   : GNATCOM.Types.BSTR;
      bstrValue  : GNATCOM.Types.BSTR;
      Free       : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PutProperty
         (Pointer (This),
          bPerLocale,
          bstrName,
          bstrValue));

      if Free then
               GNATCOM.Interface.Free (bstrName);
               GNATCOM.Interface.Free (bstrValue);
      
      end if;

   end PutProperty;

    function GetProperty
     (This       : ISearchAssistantOC_Type;
      bPerLocale : GNATCOM.Types.VARIANT_BOOL;
      bstrName   : GNATCOM.Types.BSTR;
      Free       : Boolean := True)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetProperty
         (Pointer (This),
          bPerLocale,
          bstrName,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (bstrName);
      
      end if;

      return RetVal;
   end GetProperty;

   procedure Put_EventHandled
     (This : ISearchAssistantOC_Type;
      P1   : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_EventHandled
         (Pointer (This),
          P1));

   end Put_EventHandled;

   procedure ResetNextMenu
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ResetNextMenu
         (Pointer (This)));

   end ResetNextMenu;

   procedure FindOnWeb
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FindOnWeb
         (Pointer (This)));

   end FindOnWeb;

   procedure FindFilesOrFolders
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FindFilesOrFolders
         (Pointer (This)));

   end FindFilesOrFolders;

   procedure FindComputer
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FindComputer
         (Pointer (This)));

   end FindComputer;

   procedure FindPrinter
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FindPrinter
         (Pointer (This)));

   end FindPrinter;

   procedure FindPeople
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FindPeople
         (Pointer (This)));

   end FindPeople;

    function GetSearchAssistantURL
     (This        : ISearchAssistantOC_Type;
      bSubstitute : GNATCOM.Types.VARIANT_BOOL;
      bCustomize  : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetSearchAssistantURL
         (Pointer (This),
          bSubstitute,
          bCustomize,
          RetVal'Unchecked_Access));

      return RetVal;
   end GetSearchAssistantURL;

   procedure NotifySearchSettingsChanged
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NotifySearchSettingsChanged
         (Pointer (This)));

   end NotifySearchSettingsChanged;

   procedure Put_ASProvider
     (This      : ISearchAssistantOC_Type;
      pProvider : GNATCOM.Types.BSTR;
      Free      : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ASProvider
         (Pointer (This),
          pProvider));

      if Free then
               GNATCOM.Interface.Free (pProvider);
      
      end if;

   end Put_ASProvider;

    function Get_ASProvider
     (This      : ISearchAssistantOC_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ASProvider
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ASProvider;

   procedure Put_ASSetting
     (This     : ISearchAssistantOC_Type;
      pSetting : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ASSetting
         (Pointer (This),
          pSetting));

   end Put_ASSetting;

    function Get_ASSetting
     (This     : ISearchAssistantOC_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ASSetting
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ASSetting;

   procedure NETDetectNextNavigate
     (This : ISearchAssistantOC_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NETDetectNextNavigate
         (Pointer (This)));

   end NETDetectNextNavigate;

   procedure PutFindText
     (This     : ISearchAssistantOC_Type;
      FindText : GNATCOM.Types.BSTR;
      Free     : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PutFindText
         (Pointer (This),
          FindText));

      if Free then
               GNATCOM.Interface.Free (FindText);
      
      end if;

   end PutFindText;

    function Get_Version
     (This     : ISearchAssistantOC_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Version
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Version;

    function EncodeString
     (This        : ISearchAssistantOC_Type;
      bstrValue   : GNATCOM.Types.BSTR;
      bstrCharSet : GNATCOM.Types.BSTR;
      bUseUTF8    : GNATCOM.Types.VARIANT_BOOL;
      Free        : Boolean := True)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.EncodeString
         (Pointer (This),
          bstrValue,
          bstrCharSet,
          bUseUTF8,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (bstrValue);
               GNATCOM.Interface.Free (bstrCharSet);
      
      end if;

      return RetVal;
   end EncodeString;

end IE.ISearchAssistantOC_Interface;

