with GNATCOM.Interface;

with GNATCOM.Errors;

package body MSHTML.IHTMLControlRange_Interface is

   procedure Initialize (This : in out IHTMLControlRange_Type) is
   begin
      Set_IID (This, IID_IHTMLControlRange);
   end Initialize;

   function Pointer (This : IHTMLControlRange_Type)
     return Pointer_To_IHTMLControlRange
   is
   begin
      return To_Pointer_To_IHTMLControlRange (Address (This));
   end Pointer;

   procedure Attach (This    : in out IHTMLControlRange_Type;
                     Pointer : in     Pointer_To_IHTMLControlRange)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

   procedure uselect
     (This : IHTMLControlRange_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uselect
         (Pointer (This)));

   end uselect;

   procedure add
     (This : IHTMLControlRange_Type;
      item : Pointer_To_IHTMLControlElement)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.add
         (Pointer (This),
          item));

   end add;

   procedure remove
     (This  : IHTMLControlRange_Type;
      index : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.remove
         (Pointer (This),
          index));

   end remove;

    function item
     (This  : IHTMLControlRange_Type;
      index : Interfaces.C.long)
     return Pointer_To_IHTMLElement
   is
       RetVal : aliased Pointer_To_IHTMLElement;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.item
         (Pointer (This),
          index,
          RetVal'Unchecked_Access));

      return RetVal;
   end item;

   procedure scrollIntoView
     (This        : IHTMLControlRange_Type;
      varargStart : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free        : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.scrollIntoView
         (Pointer (This),
          varargStart));

      if Free then
               GNATCOM.Interface.Free (varargStart);
      
      end if;

   end scrollIntoView;

    function queryCommandSupported
     (This  : IHTMLControlRange_Type;
      cmdID : GNATCOM.Types.BSTR;
      Free  : Boolean := True)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.queryCommandSupported
         (Pointer (This),
          cmdID,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
      
      end if;

      return RetVal;
   end queryCommandSupported;

    function queryCommandEnabled
     (This  : IHTMLControlRange_Type;
      cmdID : GNATCOM.Types.BSTR;
      Free  : Boolean := True)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.queryCommandEnabled
         (Pointer (This),
          cmdID,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
      
      end if;

      return RetVal;
   end queryCommandEnabled;

    function queryCommandState
     (This  : IHTMLControlRange_Type;
      cmdID : GNATCOM.Types.BSTR;
      Free  : Boolean := True)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.queryCommandState
         (Pointer (This),
          cmdID,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
      
      end if;

      return RetVal;
   end queryCommandState;

    function queryCommandIndeterm
     (This  : IHTMLControlRange_Type;
      cmdID : GNATCOM.Types.BSTR;
      Free  : Boolean := True)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.queryCommandIndeterm
         (Pointer (This),
          cmdID,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
      
      end if;

      return RetVal;
   end queryCommandIndeterm;

    function queryCommandText
     (This     : IHTMLControlRange_Type;
      cmdID    : GNATCOM.Types.BSTR;
      Free     : Boolean := True)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.queryCommandText
         (Pointer (This),
          cmdID,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
      
      end if;

      return RetVal;
   end queryCommandText;

    function queryCommandValue
     (This      : IHTMLControlRange_Type;
      cmdID     : GNATCOM.Types.BSTR;
      Free      : Boolean := True)
     return GNATCOM.Types.VARIANT
   is
       RetVal : aliased GNATCOM.Types.VARIANT;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.queryCommandValue
         (Pointer (This),
          cmdID,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
      
      end if;

      return RetVal;
   end queryCommandValue;

    function execCommand
     (This   : IHTMLControlRange_Type;
      cmdID  : GNATCOM.Types.BSTR;
      showUI : GNATCOM.Types.VARIANT_BOOL;
      value  : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free   : Boolean := True)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.execCommand
         (Pointer (This),
          cmdID,
          showUI,
          value,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
               GNATCOM.Interface.Free (value);
      
      end if;

      return RetVal;
   end execCommand;

    function execCommandShowHelp
     (This  : IHTMLControlRange_Type;
      cmdID : GNATCOM.Types.BSTR;
      Free  : Boolean := True)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.execCommandShowHelp
         (Pointer (This),
          cmdID,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (cmdID);
      
      end if;

      return RetVal;
   end execCommandShowHelp;

    function commonParentElement
     (This   : IHTMLControlRange_Type)
     return Pointer_To_IHTMLElement
   is
       RetVal : aliased Pointer_To_IHTMLElement;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.commonParentElement
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end commonParentElement;

    function Get_length
     (This : IHTMLControlRange_Type)
     return Interfaces.C.long
   is
       RetVal : aliased Interfaces.C.long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_length
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_length;

end MSHTML.IHTMLControlRange_Interface;

