with GNATCOM.Interface;

with GNATCOM.Errors;

package body MSHTML.IHTMLDOMNode_Interface is

   procedure Initialize (This : in out IHTMLDOMNode_Type) is
   begin
      Set_IID (This, IID_IHTMLDOMNode);
   end Initialize;

   function Pointer (This : IHTMLDOMNode_Type)
     return Pointer_To_IHTMLDOMNode
   is
   begin
      return To_Pointer_To_IHTMLDOMNode (Address (This));
   end Pointer;

   procedure Attach (This    : in out IHTMLDOMNode_Type;
                     Pointer : in     Pointer_To_IHTMLDOMNode)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_nodeType
     (This : IHTMLDOMNode_Type)
     return Interfaces.C.long
   is
       RetVal : aliased Interfaces.C.long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_nodeType
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_nodeType;

    function Get_parentNode
     (This : IHTMLDOMNode_Type)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_parentNode
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_parentNode;

    function hasChildNodes
     (This      : IHTMLDOMNode_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.hasChildNodes
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end hasChildNodes;

    function Get_childNodes
     (This : IHTMLDOMNode_Type)
     return GNATCOM.Types.Pointer_To_IDispatch
   is
       RetVal : aliased GNATCOM.Types.Pointer_To_IDispatch;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_childNodes
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_childNodes;

    function Get_attributes
     (This : IHTMLDOMNode_Type)
     return GNATCOM.Types.Pointer_To_IDispatch
   is
       RetVal : aliased GNATCOM.Types.Pointer_To_IDispatch;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_attributes
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_attributes;

    function insertBefore
     (This     : IHTMLDOMNode_Type;
      newChild : Pointer_To_IHTMLDOMNode;
      refChild : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free     : Boolean := True)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.insertBefore
         (Pointer (This),
          newChild,
          refChild,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (refChild);
      
      end if;

      return RetVal;
   end insertBefore;

    function removeChild
     (This     : IHTMLDOMNode_Type;
      oldChild : Pointer_To_IHTMLDOMNode)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.removeChild
         (Pointer (This),
          oldChild,
          RetVal'Unchecked_Access));

      return RetVal;
   end removeChild;

    function replaceChild
     (This     : IHTMLDOMNode_Type;
      newChild : Pointer_To_IHTMLDOMNode;
      oldChild : Pointer_To_IHTMLDOMNode)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.replaceChild
         (Pointer (This),
          newChild,
          oldChild,
          RetVal'Unchecked_Access));

      return RetVal;
   end replaceChild;

    function cloneNode
     (This       : IHTMLDOMNode_Type;
      fDeep      : GNATCOM.Types.VARIANT_BOOL)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.cloneNode
         (Pointer (This),
          fDeep,
          RetVal'Unchecked_Access));

      return RetVal;
   end cloneNode;

    function removeNode
     (This    : IHTMLDOMNode_Type;
      fDeep   : GNATCOM.Types.VARIANT_BOOL)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.removeNode
         (Pointer (This),
          fDeep,
          RetVal'Unchecked_Access));

      return RetVal;
   end removeNode;

    function swapNode
     (This        : IHTMLDOMNode_Type;
      otherNode   : Pointer_To_IHTMLDOMNode)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.swapNode
         (Pointer (This),
          otherNode,
          RetVal'Unchecked_Access));

      return RetVal;
   end swapNode;

    function replaceNode
     (This        : IHTMLDOMNode_Type;
      replacement : Pointer_To_IHTMLDOMNode)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.replaceNode
         (Pointer (This),
          replacement,
          RetVal'Unchecked_Access));

      return RetVal;
   end replaceNode;

    function appendChild
     (This     : IHTMLDOMNode_Type;
      newChild : Pointer_To_IHTMLDOMNode)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.appendChild
         (Pointer (This),
          newChild,
          RetVal'Unchecked_Access));

      return RetVal;
   end appendChild;

    function Get_nodeName
     (This : IHTMLDOMNode_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_nodeName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_nodeName;

   procedure Put_nodeValue
     (This : IHTMLDOMNode_Type;
      p    : GNATCOM.Types.VARIANT;
      Free : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_nodeValue
         (Pointer (This),
          p));

      if Free then
               GNATCOM.Interface.Free (p);
      
      end if;

   end Put_nodeValue;

    function Get_nodeValue
     (This : IHTMLDOMNode_Type)
     return GNATCOM.Types.VARIANT
   is
       RetVal : aliased GNATCOM.Types.VARIANT;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_nodeValue
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_nodeValue;

    function Get_firstChild
     (This : IHTMLDOMNode_Type)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_firstChild
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_firstChild;

    function Get_lastChild
     (This : IHTMLDOMNode_Type)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_lastChild
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_lastChild;

    function Get_previousSibling
     (This : IHTMLDOMNode_Type)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_previousSibling
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_previousSibling;

    function Get_nextSibling
     (This : IHTMLDOMNode_Type)
     return Pointer_To_IHTMLDOMNode
   is
       RetVal : aliased Pointer_To_IHTMLDOMNode;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_nextSibling
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_nextSibling;

end MSHTML.IHTMLDOMNode_Interface;

