with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAColor_Interface is

   procedure Initialize (This : in out IDAColor_Type) is
   begin
      Set_IID (This, IID_IDAColor);
   end Initialize;

   function Pointer (This : IDAColor_Type)
     return Pointer_To_IDAColor
   is
   begin
      return To_Pointer_To_IDAColor (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAColor_Type;
                     Pointer : in     Pointer_To_IDAColor)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDAColor_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDAColor_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDAColor_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDAColor_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDAColor_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDAColor_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDAColor_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDAColor_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDAColor_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDAColor_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDAColor_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDAColor_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDAColor_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDAColor_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function Get_Red
     (This  : IDAColor_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Red
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Red;

    function Get_Green
     (This  : IDAColor_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Green
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Green;

    function Get_Blue
     (This  : IDAColor_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Blue
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Blue;

    function Get_Hue
     (This  : IDAColor_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Hue
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Hue;

    function Get_Saturation
     (This  : IDAColor_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Saturation
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Saturation;

    function Get_Lightness
     (This  : IDAColor_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Lightness
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Lightness;

end StructuredGraphicControl.IDAColor_Interface;

