with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDADrawingSurface_Interface is

   procedure Initialize (This : in out IDADrawingSurface_Type) is
   begin
      Set_IID (This, IID_IDADrawingSurface);
   end Initialize;

   function Pointer (This : IDADrawingSurface_Type)
     return Pointer_To_IDADrawingSurface
   is
   begin
      return To_Pointer_To_IDADrawingSurface (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDADrawingSurface_Type;
                     Pointer : in     Pointer_To_IDADrawingSurface)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_Image
     (This : IDADrawingSurface_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Image
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Image;

   procedure Put_LineStyle
     (This : IDADrawingSurface_Type;
      P1   : Pointer_To_IDALineStyle)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_LineStyle
         (Pointer (This),
          P1));

   end Put_LineStyle;

   procedure Put_BorderStyle
     (This : IDADrawingSurface_Type;
      P1   : Pointer_To_IDALineStyle)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_BorderStyle
         (Pointer (This),
          P1));

   end Put_BorderStyle;

   procedure Put_FontStyle
     (This : IDADrawingSurface_Type;
      P1   : Pointer_To_IDAFontStyle)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_FontStyle
         (Pointer (This),
          P1));

   end Put_FontStyle;

   procedure Put_ClipMatte
     (This : IDADrawingSurface_Type;
      P1   : Pointer_To_IDAMatte)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ClipMatte
         (Pointer (This),
          P1));

   end Put_ClipMatte;

   procedure Put_MouseEventsEnabled
     (This : IDADrawingSurface_Type;
      P1   : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_MouseEventsEnabled
         (Pointer (This),
          P1));

   end Put_MouseEventsEnabled;

   procedure Put_HatchFillTransparent
     (This : IDADrawingSurface_Type;
      P1   : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_HatchFillTransparent
         (Pointer (This),
          P1));

   end Put_HatchFillTransparent;

    function Get_LocalContextImage
     (This : IDADrawingSurface_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_LocalContextImage
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_LocalContextImage;

   procedure Reset
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Reset
         (Pointer (This)));

   end Reset;

   procedure Clear
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Clear
         (Pointer (This)));

   end Clear;

   procedure SaveGraphicsState
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SaveGraphicsState
         (Pointer (This)));

   end SaveGraphicsState;

   procedure RestoreGraphicsState
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RestoreGraphicsState
         (Pointer (This)));

   end RestoreGraphicsState;

   procedure Opacity
     (This : IDADrawingSurface_Type;
      opac : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Opacity
         (Pointer (This),
          opac));

   end Opacity;

   procedure OpacityAnim
     (This : IDADrawingSurface_Type;
      opac : Pointer_To_IDANumber)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OpacityAnim
         (Pointer (This),
          opac));

   end OpacityAnim;

   procedure Crop
     (This        : IDADrawingSurface_Type;
      lowerLeftX  : Interfaces.C.double;
      lowerLeftY  : Interfaces.C.double;
      upperRightX : Interfaces.C.double;
      upperRightY : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Crop
         (Pointer (This),
          lowerLeftX,
          lowerLeftY,
          upperRightX,
          upperRightY));

   end Crop;

   procedure CropPoints
     (This : IDADrawingSurface_Type;
      Min  : Pointer_To_IDAPoint2;
      Max  : Pointer_To_IDAPoint2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.CropPoints
         (Pointer (This),
          Min,
          Max));

   end CropPoints;

   procedure Transform
     (This  : IDADrawingSurface_Type;
      xform : Pointer_To_IDATransform2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform
         (Pointer (This),
          xform));

   end Transform;

   procedure LineColor
     (This : IDADrawingSurface_Type;
      clr  : Pointer_To_IDAColor)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LineColor
         (Pointer (This),
          clr));

   end LineColor;

   procedure LineWidth
     (This : IDADrawingSurface_Type;
      w    : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LineWidth
         (Pointer (This),
          w));

   end LineWidth;

   procedure LineDashStyle
     (This : IDADrawingSurface_Type;
      id   : DA_DASH_STYLE)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LineDashStyle
         (Pointer (This),
          id));

   end LineDashStyle;

   procedure LineEndStyle
     (This : IDADrawingSurface_Type;
      id   : DA_END_STYLE)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LineEndStyle
         (Pointer (This),
          id));

   end LineEndStyle;

   procedure LineJoinStyle
     (This : IDADrawingSurface_Type;
      id   : DA_JOIN_STYLE)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LineJoinStyle
         (Pointer (This),
          id));

   end LineJoinStyle;

   procedure BorderColor
     (This : IDADrawingSurface_Type;
      clr  : Pointer_To_IDAColor)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.BorderColor
         (Pointer (This),
          clr));

   end BorderColor;

   procedure BorderWidth
     (This : IDADrawingSurface_Type;
      w    : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.BorderWidth
         (Pointer (This),
          w));

   end BorderWidth;

   procedure BorderDashStyle
     (This : IDADrawingSurface_Type;
      id   : DA_DASH_STYLE)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.BorderDashStyle
         (Pointer (This),
          id));

   end BorderDashStyle;

   procedure BorderEndStyle
     (This     : IDADrawingSurface_Type;
      obsolete : DA_END_STYLE)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.BorderEndStyle
         (Pointer (This),
          obsolete));

   end BorderEndStyle;

   procedure BorderJoinStyle
     (This : IDADrawingSurface_Type;
      id   : DA_JOIN_STYLE)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.BorderJoinStyle
         (Pointer (This),
          id));

   end BorderJoinStyle;

   procedure Font
     (This          : IDADrawingSurface_Type;
      FontFace      : GNATCOM.Types.BSTR;
      sizeInPoints  : Interfaces.C.long;
      Bold          : GNATCOM.Types.VARIANT_BOOL;
      Italic        : GNATCOM.Types.VARIANT_BOOL;
      Underline     : GNATCOM.Types.VARIANT_BOOL;
      Strikethrough : GNATCOM.Types.VARIANT_BOOL;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Font
         (Pointer (This),
          FontFace,
          sizeInPoints,
          Bold,
          Italic,
          Underline,
          Strikethrough));

      if Free then
               GNATCOM.Interface.Free (FontFace);
      
      end if;

   end Font;

   procedure TextureFill
     (This      : IDADrawingSurface_Type;
      obsolete1 : Pointer_To_IDAImage;
      obsolete2 : Interfaces.C.double;
      obsolete3 : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TextureFill
         (Pointer (This),
          obsolete1,
          obsolete2,
          obsolete3));

   end TextureFill;

   procedure ImageFill
     (This      : IDADrawingSurface_Type;
      obsolete1 : Pointer_To_IDAImage;
      obsolete2 : Interfaces.C.double;
      obsolete3 : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImageFill
         (Pointer (This),
          obsolete1,
          obsolete2,
          obsolete3));

   end ImageFill;

   procedure FillTexture
     (This : IDADrawingSurface_Type;
      img  : Pointer_To_IDAImage)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FillTexture
         (Pointer (This),
          img));

   end FillTexture;

   procedure FillImage
     (This : IDADrawingSurface_Type;
      img  : Pointer_To_IDAImage)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FillImage
         (Pointer (This),
          img));

   end FillImage;

   procedure FillStyle
     (This : IDADrawingSurface_Type;
      id   : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FillStyle
         (Pointer (This),
          id));

   end FillStyle;

   procedure FillColor
     (This       : IDADrawingSurface_Type;
      foreground : Pointer_To_IDAColor)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FillColor
         (Pointer (This),
          foreground));

   end FillColor;

   procedure SecondaryFillColor
     (This : IDADrawingSurface_Type;
      val  : Pointer_To_IDAColor)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SecondaryFillColor
         (Pointer (This),
          val));

   end SecondaryFillColor;

   procedure GradientShape
     (This : IDADrawingSurface_Type;
      pts  : GNATCOM.Types.VARIANT;
      Free : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientShape
         (Pointer (This),
          pts));

      if Free then
               GNATCOM.Interface.Free (pts);
      
      end if;

   end GradientShape;

   procedure GradientExtent
     (This    : IDADrawingSurface_Type;
      startx  : Interfaces.C.double;
      starty  : Interfaces.C.double;
      finishx : Interfaces.C.double;
      finishy : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientExtent
         (Pointer (This),
          startx,
          starty,
          finishx,
          finishy));

   end GradientExtent;

   procedure GradientExtentPoints
     (This       : IDADrawingSurface_Type;
      startColor : Pointer_To_IDAPoint2;
      stopColor  : Pointer_To_IDAPoint2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientExtentPoints
         (Pointer (This),
          startColor,
          stopColor));

   end GradientExtentPoints;

   procedure GradientRolloffPower
     (This  : IDADrawingSurface_Type;
      power : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientRolloffPower
         (Pointer (This),
          power));

   end GradientRolloffPower;

   procedure GradientRolloffPowerAnim
     (This  : IDADrawingSurface_Type;
      power : Pointer_To_IDANumber)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientRolloffPowerAnim
         (Pointer (This),
          power));

   end GradientRolloffPowerAnim;

   procedure FixedFillScale
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FixedFillScale
         (Pointer (This)));

   end FixedFillScale;

   procedure HorizontalFillScale
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HorizontalFillScale
         (Pointer (This)));

   end HorizontalFillScale;

   procedure VerticalFillScale
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.VerticalFillScale
         (Pointer (This)));

   end VerticalFillScale;

   procedure AutoSizeFillScale
     (This : IDADrawingSurface_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AutoSizeFillScale
         (Pointer (This)));

   end AutoSizeFillScale;

   procedure PolylineEx
     (This   : IDADrawingSurface_Type;
      numPts : Interfaces.C.long;
      pts    : Pointer_To_Pointer_To_IDAPoint2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PolylineEx
         (Pointer (This),
          numPts,
          pts));

   end PolylineEx;

   procedure Polyline
     (This : IDADrawingSurface_Type;
      v    : GNATCOM.Types.VARIANT;
      Free : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Polyline
         (Pointer (This),
          v));

      if Free then
               GNATCOM.Interface.Free (v);
      
      end if;

   end Polyline;

   procedure PolygonEx
     (This   : IDADrawingSurface_Type;
      numPts : Interfaces.C.long;
      pts    : Pointer_To_Pointer_To_IDAPoint2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PolygonEx
         (Pointer (This),
          numPts,
          pts));

   end PolygonEx;

   procedure Polygon
     (This : IDADrawingSurface_Type;
      v    : GNATCOM.Types.VARIANT;
      Free : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Polygon
         (Pointer (This),
          v));

      if Free then
               GNATCOM.Interface.Free (v);
      
      end if;

   end Polygon;

   procedure LinePoints
     (This : IDADrawingSurface_Type;
      p1   : Pointer_To_IDAPoint2;
      p2   : Pointer_To_IDAPoint2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LinePoints
         (Pointer (This),
          p1,
          p2));

   end LinePoints;

   procedure Line
     (This   : IDADrawingSurface_Type;
      startx : Interfaces.C.double;
      starty : Interfaces.C.double;
      endX   : Interfaces.C.double;
      endY   : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Line
         (Pointer (This),
          startx,
          starty,
          endX,
          endY));

   end Line;

   procedure ArcRadians
     (This       : IDADrawingSurface_Type;
      xPos       : Interfaces.C.double;
      yPos       : Interfaces.C.double;
      startAngle : Interfaces.C.double;
      endAngle   : Interfaces.C.double;
      arcWidth   : Interfaces.C.double;
      arcHeight  : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ArcRadians
         (Pointer (This),
          xPos,
          yPos,
          startAngle,
          endAngle,
          arcWidth,
          arcHeight));

   end ArcRadians;

   procedure ArcDegrees
     (This       : IDADrawingSurface_Type;
      xPos       : Interfaces.C.double;
      yPos       : Interfaces.C.double;
      startAngle : Interfaces.C.double;
      endAngle   : Interfaces.C.double;
      arcWidth   : Interfaces.C.double;
      arcHeight  : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ArcDegrees
         (Pointer (This),
          xPos,
          yPos,
          startAngle,
          endAngle,
          arcWidth,
          arcHeight));

   end ArcDegrees;

   procedure Oval
     (This : IDADrawingSurface_Type;
      xPos : Interfaces.C.double;
      yPos : Interfaces.C.double;
      w    : Interfaces.C.double;
      h    : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Oval
         (Pointer (This),
          xPos,
          yPos,
          w,
          h));

   end Oval;

   procedure Rect
     (This : IDADrawingSurface_Type;
      xPos : Interfaces.C.double;
      yPos : Interfaces.C.double;
      w    : Interfaces.C.double;
      h    : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rect
         (Pointer (This),
          xPos,
          yPos,
          w,
          h));

   end Rect;

   procedure RoundRect
     (This      : IDADrawingSurface_Type;
      xPos      : Interfaces.C.double;
      yPos      : Interfaces.C.double;
      w         : Interfaces.C.double;
      h         : Interfaces.C.double;
      arcWidth  : Interfaces.C.double;
      arcHeight : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RoundRect
         (Pointer (This),
          xPos,
          yPos,
          w,
          h,
          arcWidth,
          arcHeight));

   end RoundRect;

   procedure PieRadians
     (This       : IDADrawingSurface_Type;
      xPos       : Interfaces.C.double;
      yPos       : Interfaces.C.double;
      startAngle : Interfaces.C.double;
      endAngle   : Interfaces.C.double;
      arcWidth   : Interfaces.C.double;
      arcHeight  : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PieRadians
         (Pointer (This),
          xPos,
          yPos,
          startAngle,
          endAngle,
          arcWidth,
          arcHeight));

   end PieRadians;

   procedure PieDegrees
     (This       : IDADrawingSurface_Type;
      xPos       : Interfaces.C.double;
      yPos       : Interfaces.C.double;
      startAngle : Interfaces.C.double;
      endAngle   : Interfaces.C.double;
      arcWidth   : Interfaces.C.double;
      arcHeight  : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PieDegrees
         (Pointer (This),
          xPos,
          yPos,
          startAngle,
          endAngle,
          arcWidth,
          arcHeight));

   end PieDegrees;

   procedure Text
     (This : IDADrawingSurface_Type;
      str  : GNATCOM.Types.BSTR;
      xPos : Interfaces.C.double;
      yPos : Interfaces.C.double;
      Free : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Text
         (Pointer (This),
          str,
          xPos,
          yPos));

      if Free then
               GNATCOM.Interface.Free (str);
      
      end if;

   end Text;

   procedure TextPoint
     (This  : IDADrawingSurface_Type;
      str   : GNATCOM.Types.BSTR;
      point : Pointer_To_IDAPoint2;
      Free  : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TextPoint
         (Pointer (This),
          str,
          point));

      if Free then
               GNATCOM.Interface.Free (str);
      
      end if;

   end TextPoint;

   procedure FillPath
     (This : IDADrawingSurface_Type;
      path : Pointer_To_IDAPath2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FillPath
         (Pointer (This),
          path));

   end FillPath;

   procedure DrawPath
     (This : IDADrawingSurface_Type;
      path : Pointer_To_IDAPath2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DrawPath
         (Pointer (This),
          path));

   end DrawPath;

   procedure OverlayImage
     (This : IDADrawingSurface_Type;
      img  : Pointer_To_IDAImage)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OverlayImage
         (Pointer (This),
          img));

   end OverlayImage;

end StructuredGraphicControl.IDADrawingSurface_Interface;

