with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAEvent_Interface is

   procedure Initialize (This : in out IDAEvent_Type) is
   begin
      Set_IID (This, IID_IDAEvent);
   end Initialize;

   function Pointer (This : IDAEvent_Type)
     return Pointer_To_IDAEvent
   is
   begin
      return To_Pointer_To_IDAEvent (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAEvent_Type;
                     Pointer : in     Pointer_To_IDAEvent)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDAEvent_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDAEvent_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDAEvent_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDAEvent_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDAEvent_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDAEvent_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDAEvent_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDAEvent_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDAEvent_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDAEvent_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDAEvent_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDAEvent_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDAEvent_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDAEvent_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function Notify
     (This       : IDAEvent_Type;
      notifier_0 : Pointer_To_IDAUntilNotifier)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Notify
         (Pointer (This),
          notifier_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Notify;

    function Snapshot
     (This  : IDAEvent_Type;
      b_0   : Pointer_To_IDABehavior)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Snapshot
         (Pointer (This),
          b_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Snapshot;

    function AttachData
     (This   : IDAEvent_Type;
      data_0 : Pointer_To_IDABehavior)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AttachData
         (Pointer (This),
          data_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end AttachData;

    function ScriptCallback
     (This        : IDAEvent_Type;
      scriptlet_0 : GNATCOM.Types.BSTR;
      language_1  : GNATCOM.Types.BSTR;
      Free        : Boolean := True)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ScriptCallback
         (Pointer (This),
          scriptlet_0,
          language_1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (scriptlet_0);
               GNATCOM.Interface.Free (language_1);
      
      end if;

      return RetVal;
   end ScriptCallback;

end StructuredGraphicControl.IDAEvent_Interface;

