with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAGeometry_Interface is

   procedure Initialize (This : in out IDAGeometry_Type) is
   begin
      Set_IID (This, IID_IDAGeometry);
   end Initialize;

   function Pointer (This : IDAGeometry_Type)
     return Pointer_To_IDAGeometry
   is
   begin
      return To_Pointer_To_IDAGeometry (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAGeometry_Type;
                     Pointer : in     Pointer_To_IDAGeometry)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDAGeometry_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDAGeometry_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDAGeometry_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDAGeometry_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDAGeometry_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDAGeometry_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDAGeometry_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDAGeometry_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDAGeometry_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDAGeometry_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDAGeometry_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDAGeometry_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDAGeometry_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDAGeometry_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function RenderSound
     (This  : IDAGeometry_Type;
      mic_0 : Pointer_To_IDAMicrophone)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RenderSound
         (Pointer (This),
          mic_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end RenderSound;

    function Pickable
     (This  : IDAGeometry_Type)
     return Pointer_To_IDAPickableResult
   is
       RetVal : aliased Pointer_To_IDAPickableResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Pickable
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Pickable;

    function PickableOccluded
     (This  : IDAGeometry_Type)
     return Pointer_To_IDAPickableResult
   is
       RetVal : aliased Pointer_To_IDAPickableResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PickableOccluded
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end PickableOccluded;

    function Undetectable
     (This  : IDAGeometry_Type)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Undetectable
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Undetectable;

    function EmissiveColor
     (This  : IDAGeometry_Type;
      col_0 : Pointer_To_IDAColor)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.EmissiveColor
         (Pointer (This),
          col_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end EmissiveColor;

    function DiffuseColor
     (This  : IDAGeometry_Type;
      col_0 : Pointer_To_IDAColor)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DiffuseColor
         (Pointer (This),
          col_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DiffuseColor;

    function SpecularColor
     (This  : IDAGeometry_Type;
      col_0 : Pointer_To_IDAColor)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SpecularColor
         (Pointer (This),
          col_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end SpecularColor;

    function SpecularExponent
     (This    : IDAGeometry_Type;
      power_0 : Interfaces.C.double)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SpecularExponent
         (Pointer (This),
          power_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end SpecularExponent;

    function SpecularExponentAnim
     (This    : IDAGeometry_Type;
      power_0 : Pointer_To_IDANumber)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SpecularExponentAnim
         (Pointer (This),
          power_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end SpecularExponentAnim;

    function Texture
     (This      : IDAGeometry_Type;
      texture_0 : Pointer_To_IDAImage)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Texture
         (Pointer (This),
          texture_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Texture;

    function Opacity
     (This    : IDAGeometry_Type;
      level_0 : Interfaces.C.double)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Opacity
         (Pointer (This),
          level_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Opacity;

    function OpacityAnim
     (This    : IDAGeometry_Type;
      level_0 : Pointer_To_IDANumber)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OpacityAnim
         (Pointer (This),
          level_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end OpacityAnim;

    function Transform
     (This  : IDAGeometry_Type;
      xf_0  : Pointer_To_IDATransform3)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform
         (Pointer (This),
          xf_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Transform;

    function Get_BoundingBox
     (This  : IDAGeometry_Type)
     return Pointer_To_IDABbox3
   is
       RetVal : aliased Pointer_To_IDABbox3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_BoundingBox
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_BoundingBox;

    function Render
     (This  : IDAGeometry_Type;
      cam_0 : Pointer_To_IDACamera)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Render
         (Pointer (This),
          cam_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Render;

    function LightColor
     (This    : IDAGeometry_Type;
      color_0 : Pointer_To_IDAColor)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LightColor
         (Pointer (This),
          color_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end LightColor;

    function LightAttenuationAnim
     (This        : IDAGeometry_Type;
      constant_0  : Pointer_To_IDANumber;
      linear_1    : Pointer_To_IDANumber;
      quadratic_2 : Pointer_To_IDANumber)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LightAttenuationAnim
         (Pointer (This),
          constant_0,
          linear_1,
          quadratic_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end LightAttenuationAnim;

    function LightAttenuation
     (This        : IDAGeometry_Type;
      constant_0  : Interfaces.C.double;
      linear_1    : Interfaces.C.double;
      quadratic_2 : Interfaces.C.double)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LightAttenuation
         (Pointer (This),
          constant_0,
          linear_1,
          quadratic_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end LightAttenuation;

end StructuredGraphicControl.IDAGeometry_Interface;

