with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAImage_Interface is

   procedure Initialize (This : in out IDAImage_Type) is
   begin
      Set_IID (This, IID_IDAImage);
   end Initialize;

   function Pointer (This : IDAImage_Type)
     return Pointer_To_IDAImage
   is
   begin
      return To_Pointer_To_IDAImage (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAImage_Type;
                     Pointer : in     Pointer_To_IDAImage)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDAImage_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDAImage_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDAImage_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDAImage_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDAImage_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDAImage_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDAImage_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDAImage_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDAImage_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDAImage_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDAImage_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDAImage_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDAImage_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDAImage_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function Pickable
     (This  : IDAImage_Type)
     return Pointer_To_IDAPickableResult
   is
       RetVal : aliased Pointer_To_IDAPickableResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Pickable
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Pickable;

    function PickableOccluded
     (This  : IDAImage_Type)
     return Pointer_To_IDAPickableResult
   is
       RetVal : aliased Pointer_To_IDAPickableResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PickableOccluded
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end PickableOccluded;

    function ApplyBitmapEffect
     (This               : IDAImage_Type;
      effectToApply_0    : GNATCOM.Types.Pointer_To_IUnknown;
      firesWhenChanged_1 : Pointer_To_IDAEvent)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ApplyBitmapEffect
         (Pointer (This),
          effectToApply_0,
          firesWhenChanged_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ApplyBitmapEffect;

    function Get_BoundingBox
     (This  : IDAImage_Type)
     return Pointer_To_IDABbox2
   is
       RetVal : aliased Pointer_To_IDABbox2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_BoundingBox
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_BoundingBox;

    function Crop
     (This  : IDAImage_Type;
      min_0 : Pointer_To_IDAPoint2;
      max_1 : Pointer_To_IDAPoint2)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Crop
         (Pointer (This),
          min_0,
          max_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Crop;

    function Transform
     (This  : IDAImage_Type;
      xf_0  : Pointer_To_IDATransform2)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform
         (Pointer (This),
          xf_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Transform;

    function OpacityAnim
     (This      : IDAImage_Type;
      opacity_0 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OpacityAnim
         (Pointer (This),
          opacity_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end OpacityAnim;

    function Opacity
     (This      : IDAImage_Type;
      opacity_0 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Opacity
         (Pointer (This),
          opacity_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Opacity;

    function Undetectable
     (This  : IDAImage_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Undetectable
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Undetectable;

    function Tile
     (This  : IDAImage_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Tile
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Tile;

    function Clip
     (This  : IDAImage_Type;
      m_0   : Pointer_To_IDAMatte)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Clip
         (Pointer (This),
          m_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Clip;

    function MapToUnitSquare
     (This  : IDAImage_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.MapToUnitSquare
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end MapToUnitSquare;

    function ClipPolygonImageEx
     (This         : IDAImage_Type;
      points_0size : Interfaces.C.long;
      points_0     : Pointer_To_Pointer_To_IDAPoint2)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ClipPolygonImageEx
         (Pointer (This),
          points_0size,
          points_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ClipPolygonImageEx;

    function ClipPolygonImage
     (This     : IDAImage_Type;
      points_0 : GNATCOM.Types.VARIANT;
      Free     : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ClipPolygonImage
         (Pointer (This),
          points_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (points_0);
      
      end if;

      return RetVal;
   end ClipPolygonImage;

end StructuredGraphicControl.IDAImage_Interface;

