with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDALineStyle_Interface is

   procedure Initialize (This : in out IDALineStyle_Type) is
   begin
      Set_IID (This, IID_IDALineStyle);
   end Initialize;

   function Pointer (This : IDALineStyle_Type)
     return Pointer_To_IDALineStyle
   is
   begin
      return To_Pointer_To_IDALineStyle (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDALineStyle_Type;
                     Pointer : in     Pointer_To_IDALineStyle)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDALineStyle_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDALineStyle_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDALineStyle_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDALineStyle_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDALineStyle_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDALineStyle_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDALineStyle_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDALineStyle_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDALineStyle_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDALineStyle_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDALineStyle_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDALineStyle_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDALineStyle_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDALineStyle_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function uEnd
     (This       : IDALineStyle_Type;
      obsolete_0 : Pointer_To_IDAEndStyle)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uEnd
         (Pointer (This),
          obsolete_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end uEnd;

    function Join
     (This       : IDALineStyle_Type;
      obsolete_0 : Pointer_To_IDAJoinStyle)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Join
         (Pointer (This),
          obsolete_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Join;

    function Dash
     (This       : IDALineStyle_Type;
      obsolete_0 : Pointer_To_IDADashStyle)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Dash
         (Pointer (This),
          obsolete_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Dash;

    function WidthAnim
     (This  : IDALineStyle_Type;
      sty_0 : Pointer_To_IDANumber)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.WidthAnim
         (Pointer (This),
          sty_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end WidthAnim;

    function width
     (This  : IDALineStyle_Type;
      sty_0 : Interfaces.C.double)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.width
         (Pointer (This),
          sty_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end width;

    function AntiAliasing
     (This      : IDALineStyle_Type;
      aaStyle_0 : Interfaces.C.double)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AntiAliasing
         (Pointer (This),
          aaStyle_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end AntiAliasing;

    function Detail
     (This  : IDALineStyle_Type)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Detail
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Detail;

    function Color
     (This  : IDALineStyle_Type;
      clr_0 : Pointer_To_IDAColor)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Color
         (Pointer (This),
          clr_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Color;

end StructuredGraphicControl.IDALineStyle_Interface;

