with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDANumber_Interface is

   procedure Initialize (This : in out IDANumber_Type) is
   begin
      Set_IID (This, IID_IDANumber);
   end Initialize;

   function Pointer (This : IDANumber_Type)
     return Pointer_To_IDANumber
   is
   begin
      return To_Pointer_To_IDANumber (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDANumber_Type;
                     Pointer : in     Pointer_To_IDANumber)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDANumber_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDANumber_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDANumber_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDANumber_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDANumber_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDANumber_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDANumber_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDANumber_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDANumber_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDANumber_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDANumber_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDANumber_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDANumber_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDANumber_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function Extract
     (This  : IDANumber_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Extract
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Extract;

    function AnimateProperty
     (This                : IDANumber_Type;
      propertyPath_0      : GNATCOM.Types.BSTR;
      scriptingLanguage_1 : GNATCOM.Types.BSTR;
      invokeAsMethod_2    : GNATCOM.Types.VARIANT_BOOL;
      minUpdateInterval_3 : Interfaces.C.double;
      Free                : Boolean := True)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AnimateProperty
         (Pointer (This),
          propertyPath_0,
          scriptingLanguage_1,
          invokeAsMethod_2,
          minUpdateInterval_3,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (propertyPath_0);
               GNATCOM.Interface.Free (scriptingLanguage_1);
      
      end if;

      return RetVal;
   end AnimateProperty;

    function ToStringAnim
     (This        : IDANumber_Type;
      precision_0 : Pointer_To_IDANumber)
     return Pointer_To_IDAString
   is
       RetVal : aliased Pointer_To_IDAString;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ToStringAnim
         (Pointer (This),
          precision_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ToStringAnim;

    function ToString
     (This        : IDANumber_Type;
      precision_0 : Interfaces.C.double)
     return Pointer_To_IDAString
   is
       RetVal : aliased Pointer_To_IDAString;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ToString
         (Pointer (This),
          precision_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ToString;

end StructuredGraphicControl.IDANumber_Interface;

