with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAPath2_Interface is

   procedure Initialize (This : in out IDAPath2_Type) is
   begin
      Set_IID (This, IID_IDAPath2);
   end Initialize;

   function Pointer (This : IDAPath2_Type)
     return Pointer_To_IDAPath2
   is
   begin
      return To_Pointer_To_IDAPath2 (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAPath2_Type;
                     Pointer : in     Pointer_To_IDAPath2)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDAPath2_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDAPath2_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDAPath2_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDAPath2_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDAPath2_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDAPath2_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDAPath2_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDAPath2_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDAPath2_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDAPath2_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDAPath2_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDAPath2_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDAPath2_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDAPath2_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function Transform
     (This  : IDAPath2_Type;
      xf_0  : Pointer_To_IDATransform2)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform
         (Pointer (This),
          xf_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Transform;

    function BoundingBox
     (This    : IDAPath2_Type;
      style_0 : Pointer_To_IDALineStyle)
     return Pointer_To_IDABbox2
   is
       RetVal : aliased Pointer_To_IDABbox2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.BoundingBox
         (Pointer (This),
          style_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end BoundingBox;

    function Fill
     (This     : IDAPath2_Type;
      border_0 : Pointer_To_IDALineStyle;
      fill_1   : Pointer_To_IDAImage)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Fill
         (Pointer (This),
          border_0,
          fill_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Fill;

    function Draw
     (This     : IDAPath2_Type;
      border_0 : Pointer_To_IDALineStyle)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Draw
         (Pointer (This),
          border_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Draw;

    function Close
     (This  : IDAPath2_Type)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Close
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Close;

end StructuredGraphicControl.IDAPath2_Interface;

