with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAPoint2_Interface is

   procedure Initialize (This : in out IDAPoint2_Type) is
   begin
      Set_IID (This, IID_IDAPoint2);
   end Initialize;

   function Pointer (This : IDAPoint2_Type)
     return Pointer_To_IDAPoint2
   is
   begin
      return To_Pointer_To_IDAPoint2 (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAPoint2_Type;
                     Pointer : in     Pointer_To_IDAPoint2)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDAPoint2_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDAPoint2_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDAPoint2_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDAPoint2_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDAPoint2_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDAPoint2_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDAPoint2_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDAPoint2_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDAPoint2_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDAPoint2_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDAPoint2_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDAPoint2_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDAPoint2_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDAPoint2_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function AnimateControlPosition
     (This                : IDAPoint2_Type;
      propertyPath_0      : GNATCOM.Types.BSTR;
      scriptingLanguage_1 : GNATCOM.Types.BSTR;
      invokeAsMethod_2    : GNATCOM.Types.VARIANT_BOOL;
      minUpdateInterval_3 : Interfaces.C.double;
      Free                : Boolean := True)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AnimateControlPosition
         (Pointer (This),
          propertyPath_0,
          scriptingLanguage_1,
          invokeAsMethod_2,
          minUpdateInterval_3,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (propertyPath_0);
               GNATCOM.Interface.Free (scriptingLanguage_1);
      
      end if;

      return RetVal;
   end AnimateControlPosition;

    function AnimateControlPositionPixel
     (This                : IDAPoint2_Type;
      propertyPath_0      : GNATCOM.Types.BSTR;
      scriptingLanguage_1 : GNATCOM.Types.BSTR;
      invokeAsMethod_2    : GNATCOM.Types.VARIANT_BOOL;
      minUpdateInterval_3 : Interfaces.C.double;
      Free                : Boolean := True)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AnimateControlPositionPixel
         (Pointer (This),
          propertyPath_0,
          scriptingLanguage_1,
          invokeAsMethod_2,
          minUpdateInterval_3,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (propertyPath_0);
               GNATCOM.Interface.Free (scriptingLanguage_1);
      
      end if;

      return RetVal;
   end AnimateControlPositionPixel;

    function Get_X
     (This  : IDAPoint2_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_X
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_X;

    function Get_Y
     (This  : IDAPoint2_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Y
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Y;

    function Get_PolarCoordAngle
     (This  : IDAPoint2_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PolarCoordAngle
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PolarCoordAngle;

    function Get_PolarCoordLength
     (This  : IDAPoint2_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PolarCoordLength
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PolarCoordLength;

    function Transform
     (This  : IDAPoint2_Type;
      xf_0  : Pointer_To_IDATransform2)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform
         (Pointer (This),
          xf_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Transform;

end StructuredGraphicControl.IDAPoint2_Interface;

