with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDASound_Interface is

   procedure Initialize (This : in out IDASound_Type) is
   begin
      Set_IID (This, IID_IDASound);
   end Initialize;

   function Pointer (This : IDASound_Type)
     return Pointer_To_IDASound
   is
   begin
      return To_Pointer_To_IDASound (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDASound_Type;
                     Pointer : in     Pointer_To_IDASound)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDASound_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDASound_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDASound_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDASound_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDASound_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDASound_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDASound_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDASound_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDASound_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDASound_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDASound_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDASound_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDASound_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDASound_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function PhaseAnim
     (This       : IDASound_Type;
      phaseAmt_0 : Pointer_To_IDANumber)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PhaseAnim
         (Pointer (This),
          phaseAmt_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end PhaseAnim;

    function Phase
     (This       : IDASound_Type;
      phaseAmt_0 : Interfaces.C.double)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Phase
         (Pointer (This),
          phaseAmt_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Phase;

    function RateAnim
     (This         : IDASound_Type;
      pitchShift_0 : Pointer_To_IDANumber)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RateAnim
         (Pointer (This),
          pitchShift_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end RateAnim;

    function Rate
     (This         : IDASound_Type;
      pitchShift_0 : Interfaces.C.double)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rate
         (Pointer (This),
          pitchShift_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rate;

    function PanAnim
     (This     : IDASound_Type;
      panAmt_0 : Pointer_To_IDANumber)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PanAnim
         (Pointer (This),
          panAmt_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end PanAnim;

    function Pan
     (This     : IDASound_Type;
      panAmt_0 : Interfaces.C.double)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Pan
         (Pointer (This),
          panAmt_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Pan;

    function GainAnim
     (This      : IDASound_Type;
      gainAmt_0 : Pointer_To_IDANumber)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GainAnim
         (Pointer (This),
          gainAmt_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end GainAnim;

    function Gain
     (This      : IDASound_Type;
      gainAmt_0 : Interfaces.C.double)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Gain
         (Pointer (This),
          gainAmt_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Gain;

    function uLoop
     (This  : IDASound_Type)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uLoop
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end uLoop;

end StructuredGraphicControl.IDASound_Interface;

