with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAStatics_Interface is

   procedure Initialize (This : in out IDAStatics_Type) is
   begin
      Set_IID (This, IID_IDAStatics);
   end Initialize;

   function Pointer (This : IDAStatics_Type)
     return Pointer_To_IDAStatics
   is
   begin
      return To_Pointer_To_IDAStatics (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAStatics_Type;
                     Pointer : in     Pointer_To_IDAStatics)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_VersionString
     (This : IDAStatics_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_VersionString
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_VersionString;

    function Get_Site
     (This  : IDAStatics_Type)
     return Pointer_To_IDASite
   is
       RetVal : aliased Pointer_To_IDASite;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Site
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Site;

   procedure Put_Site
     (This  : IDAStatics_Type;
      pSite : Pointer_To_IDASite)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Site
         (Pointer (This),
          pSite));

   end Put_Site;

   procedure Put_ClientSite
     (This        : IDAStatics_Type;
      pClientSite : Pointer_To_IOleClientSite)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ClientSite
         (Pointer (This),
          pClientSite));

   end Put_ClientSite;

    function Get_ClientSite
     (This        : IDAStatics_Type)
     return Pointer_To_IOleClientSite
   is
       RetVal : aliased Pointer_To_IOleClientSite;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ClientSite
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ClientSite;

   procedure Put_PixelConstructionMode
     (This  : IDAStatics_Type;
      bMode : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_PixelConstructionMode
         (Pointer (This),
          bMode));

   end Put_PixelConstructionMode;

    function Get_PixelConstructionMode
     (This  : IDAStatics_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PixelConstructionMode
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PixelConstructionMode;

   procedure TriggerEvent
     (This  : IDAStatics_Type;
      event : Pointer_To_IDAEvent;
      Data  : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TriggerEvent
         (Pointer (This),
          event,
          Data));

   end TriggerEvent;

    function NewDrawingSurface
     (This : IDAStatics_Type)
     return Pointer_To_IDADrawingSurface
   is
       RetVal : aliased Pointer_To_IDADrawingSurface;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NewDrawingSurface
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end NewDrawingSurface;

    function ImportMovie
     (This     : IDAStatics_Type;
      url      : GNATCOM.Types.BSTR;
      Free     : Boolean := True)
     return Pointer_To_IDAImportationResult
   is
       RetVal : aliased Pointer_To_IDAImportationResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportMovie
         (Pointer (This),
          url,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportMovie;

    function ImportMovieAsync
     (This          : IDAStatics_Type;
      url           : GNATCOM.Types.BSTR;
      pImageStandIn : Pointer_To_IDAImage;
      pSoundStandIn : Pointer_To_IDASound;
      Free          : Boolean := True)
     return Pointer_To_IDAImportationResult
   is
       RetVal : aliased Pointer_To_IDAImportationResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportMovieAsync
         (Pointer (This),
          url,
          pImageStandIn,
          pSoundStandIn,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportMovieAsync;

    function ImportImage
     (This    : IDAStatics_Type;
      url     : GNATCOM.Types.BSTR;
      Free    : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportImage
         (Pointer (This),
          url,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportImage;

    function ImportImageAsync
     (This          : IDAStatics_Type;
      url           : GNATCOM.Types.BSTR;
      pImageStandIn : Pointer_To_IDAImage;
      Free          : Boolean := True)
     return Pointer_To_IDAImportationResult
   is
       RetVal : aliased Pointer_To_IDAImportationResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportImageAsync
         (Pointer (This),
          url,
          pImageStandIn,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportImageAsync;

    function ImportImageColorKey
     (This          : IDAStatics_Type;
      url           : GNATCOM.Types.BSTR;
      colorKeyRed   : Interfaces.C.unsigned_char;
      colorKeyGreen : Interfaces.C.unsigned_char;
      colorKeyBlue  : Interfaces.C.unsigned_char;
      Free          : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportImageColorKey
         (Pointer (This),
          url,
          colorKeyRed,
          colorKeyGreen,
          colorKeyBlue,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportImageColorKey;

    function ImportImageAsyncColorKey
     (This          : IDAStatics_Type;
      url           : GNATCOM.Types.BSTR;
      pImageStandIn : Pointer_To_IDAImage;
      colorKeyRed   : Interfaces.C.unsigned_char;
      colorKeyGreen : Interfaces.C.unsigned_char;
      colorKeyBlue  : Interfaces.C.unsigned_char;
      Free          : Boolean := True)
     return Pointer_To_IDAImportationResult
   is
       RetVal : aliased Pointer_To_IDAImportationResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportImageAsyncColorKey
         (Pointer (This),
          url,
          pImageStandIn,
          colorKeyRed,
          colorKeyGreen,
          colorKeyBlue,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportImageAsyncColorKey;

    function ImportSound
     (This     : IDAStatics_Type;
      url      : GNATCOM.Types.BSTR;
      Free     : Boolean := True)
     return Pointer_To_IDAImportationResult
   is
       RetVal : aliased Pointer_To_IDAImportationResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportSound
         (Pointer (This),
          url,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportSound;

    function ImportSoundAsync
     (This          : IDAStatics_Type;
      url           : GNATCOM.Types.BSTR;
      pSoundStandIn : Pointer_To_IDASound;
      Free          : Boolean := True)
     return Pointer_To_IDAImportationResult
   is
       RetVal : aliased Pointer_To_IDAImportationResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportSoundAsync
         (Pointer (This),
          url,
          pSoundStandIn,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportSoundAsync;

    function ImportGeometry
     (This       : IDAStatics_Type;
      url        : GNATCOM.Types.BSTR;
      Free       : Boolean := True)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportGeometry
         (Pointer (This),
          url,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportGeometry;

    function ImportGeometryAsync
     (This        : IDAStatics_Type;
      url         : GNATCOM.Types.BSTR;
      pGeoStandIn : Pointer_To_IDAGeometry;
      Free        : Boolean := True)
     return Pointer_To_IDAImportationResult
   is
       RetVal : aliased Pointer_To_IDAImportationResult;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportGeometryAsync
         (Pointer (This),
          url,
          pGeoStandIn,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (url);
      
      end if;

      return RetVal;
   end ImportGeometryAsync;

    function ImportDirectDrawSurface
     (This        : IDAStatics_Type;
      dds         : GNATCOM.Types.Pointer_To_IUnknown;
      updateEvent : Pointer_To_IDAEvent)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImportDirectDrawSurface
         (Pointer (This),
          dds,
          updateEvent,
          RetVal'Unchecked_Access));

      return RetVal;
   end ImportDirectDrawSurface;

    function Cond
     (This     : IDAStatics_Type;
      c        : Pointer_To_IDABoolean;
      i        : Pointer_To_IDABehavior;
      e        : Pointer_To_IDABehavior)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Cond
         (Pointer (This),
          c,
          i,
          e,
          RetVal'Unchecked_Access));

      return RetVal;
   end Cond;

    function DAArrayEx
     (This  : IDAStatics_Type;
      s     : Interfaces.C.long;
      pBvrs : Pointer_To_Pointer_To_IDABehavior)
     return Pointer_To_IDAArray
   is
       RetVal : aliased Pointer_To_IDAArray;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DAArrayEx
         (Pointer (This),
          s,
          pBvrs,
          RetVal'Unchecked_Access));

      return RetVal;
   end DAArrayEx;

    function DAArray
     (This : IDAStatics_Type;
      bvrs : GNATCOM.Types.VARIANT;
      Free : Boolean := True)
     return Pointer_To_IDAArray
   is
       RetVal : aliased Pointer_To_IDAArray;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DAArray
         (Pointer (This),
          bvrs,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (bvrs);
      
      end if;

      return RetVal;
   end DAArray;

    function DATupleEx
     (This  : IDAStatics_Type;
      s     : Interfaces.C.long;
      pBvrs : Pointer_To_Pointer_To_IDABehavior)
     return Pointer_To_IDATuple
   is
       RetVal : aliased Pointer_To_IDATuple;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DATupleEx
         (Pointer (This),
          s,
          pBvrs,
          RetVal'Unchecked_Access));

      return RetVal;
   end DATupleEx;

    function DATuple
     (This : IDAStatics_Type;
      bvrs : GNATCOM.Types.VARIANT;
      Free : Boolean := True)
     return Pointer_To_IDATuple
   is
       RetVal : aliased Pointer_To_IDATuple;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DATuple
         (Pointer (This),
          bvrs,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (bvrs);
      
      end if;

      return RetVal;
   end DATuple;

    function ModifiableBehavior
     (This : IDAStatics_Type;
      orig : Pointer_To_IDABehavior)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ModifiableBehavior
         (Pointer (This),
          orig,
          RetVal'Unchecked_Access));

      return RetVal;
   end ModifiableBehavior;

    function UninitializedArray
     (This    : IDAStatics_Type;
      typeTmp : Pointer_To_IDAArray)
     return Pointer_To_IDAArray
   is
       RetVal : aliased Pointer_To_IDAArray;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UninitializedArray
         (Pointer (This),
          typeTmp,
          RetVal'Unchecked_Access));

      return RetVal;
   end UninitializedArray;

    function UninitializedTuple
     (This    : IDAStatics_Type;
      typeTmp : Pointer_To_IDATuple)
     return Pointer_To_IDATuple
   is
       RetVal : aliased Pointer_To_IDATuple;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UninitializedTuple
         (Pointer (This),
          typeTmp,
          RetVal'Unchecked_Access));

      return RetVal;
   end UninitializedTuple;

    function NumberBSplineEx
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      numKnots  : Interfaces.C.long;
      knots     : Pointer_To_Pointer_To_IDANumber;
      numPts    : Interfaces.C.long;
      ctrlPts   : Pointer_To_Pointer_To_IDANumber;
      numWts    : Interfaces.C.long;
      weights   : Pointer_To_Pointer_To_IDANumber;
      evaluator : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NumberBSplineEx
         (Pointer (This),
          degree,
          numKnots,
          knots,
          numPts,
          ctrlPts,
          numWts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      return RetVal;
   end NumberBSplineEx;

    function NumberBSpline
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      knots     : GNATCOM.Types.VARIANT;
      ctrlPts   : GNATCOM.Types.VARIANT;
      weights   : GNATCOM.Types.VARIANT;
      evaluator : Pointer_To_IDANumber;
      Free      : Boolean := True)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NumberBSpline
         (Pointer (This),
          degree,
          knots,
          ctrlPts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (knots);
               GNATCOM.Interface.Free (ctrlPts);
               GNATCOM.Interface.Free (weights);
      
      end if;

      return RetVal;
   end NumberBSpline;

    function Point2BSplineEx
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      numKnots  : Interfaces.C.long;
      knots     : Pointer_To_Pointer_To_IDANumber;
      numPts    : Interfaces.C.long;
      ctrlPts   : Pointer_To_Pointer_To_IDAPoint2;
      numWts    : Interfaces.C.long;
      weights   : Pointer_To_Pointer_To_IDANumber;
      evaluator : Pointer_To_IDANumber)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point2BSplineEx
         (Pointer (This),
          degree,
          numKnots,
          knots,
          numPts,
          ctrlPts,
          numWts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point2BSplineEx;

    function Point2BSpline
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      knots     : GNATCOM.Types.VARIANT;
      ctrlPts   : GNATCOM.Types.VARIANT;
      weights   : GNATCOM.Types.VARIANT;
      evaluator : Pointer_To_IDANumber;
      Free      : Boolean := True)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point2BSpline
         (Pointer (This),
          degree,
          knots,
          ctrlPts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (knots);
               GNATCOM.Interface.Free (ctrlPts);
               GNATCOM.Interface.Free (weights);
      
      end if;

      return RetVal;
   end Point2BSpline;

    function Point3BSplineEx
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      numKnots  : Interfaces.C.long;
      knots     : Pointer_To_Pointer_To_IDANumber;
      numPts    : Interfaces.C.long;
      ctrlPts   : Pointer_To_Pointer_To_IDAPoint3;
      numWts    : Interfaces.C.long;
      weights   : Pointer_To_Pointer_To_IDANumber;
      evaluator : Pointer_To_IDANumber)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point3BSplineEx
         (Pointer (This),
          degree,
          numKnots,
          knots,
          numPts,
          ctrlPts,
          numWts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point3BSplineEx;

    function Point3BSpline
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      knots     : GNATCOM.Types.VARIANT;
      ctrlPts   : GNATCOM.Types.VARIANT;
      weights   : GNATCOM.Types.VARIANT;
      evaluator : Pointer_To_IDANumber;
      Free      : Boolean := True)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point3BSpline
         (Pointer (This),
          degree,
          knots,
          ctrlPts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (knots);
               GNATCOM.Interface.Free (ctrlPts);
               GNATCOM.Interface.Free (weights);
      
      end if;

      return RetVal;
   end Point3BSpline;

    function Vector2BSplineEx
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      numKnots  : Interfaces.C.long;
      knots     : Pointer_To_Pointer_To_IDANumber;
      numPts    : Interfaces.C.long;
      ctrlPts   : Pointer_To_Pointer_To_IDAVector2;
      numWts    : Interfaces.C.long;
      weights   : Pointer_To_Pointer_To_IDANumber;
      evaluator : Pointer_To_IDANumber)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector2BSplineEx
         (Pointer (This),
          degree,
          numKnots,
          knots,
          numPts,
          ctrlPts,
          numWts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector2BSplineEx;

    function Vector2BSpline
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      knots     : GNATCOM.Types.VARIANT;
      ctrlPts   : GNATCOM.Types.VARIANT;
      weights   : GNATCOM.Types.VARIANT;
      evaluator : Pointer_To_IDANumber;
      Free      : Boolean := True)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector2BSpline
         (Pointer (This),
          degree,
          knots,
          ctrlPts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (knots);
               GNATCOM.Interface.Free (ctrlPts);
               GNATCOM.Interface.Free (weights);
      
      end if;

      return RetVal;
   end Vector2BSpline;

    function Vector3BSplineEx
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      numKnots  : Interfaces.C.long;
      knots     : Pointer_To_Pointer_To_IDANumber;
      numPts    : Interfaces.C.long;
      ctrlPts   : Pointer_To_Pointer_To_IDAVector3;
      numWts    : Interfaces.C.long;
      weights   : Pointer_To_Pointer_To_IDANumber;
      evaluator : Pointer_To_IDANumber)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector3BSplineEx
         (Pointer (This),
          degree,
          numKnots,
          knots,
          numPts,
          ctrlPts,
          numWts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector3BSplineEx;

    function Vector3BSpline
     (This      : IDAStatics_Type;
      degree    : Interfaces.C.int;
      knots     : GNATCOM.Types.VARIANT;
      ctrlPts   : GNATCOM.Types.VARIANT;
      weights   : GNATCOM.Types.VARIANT;
      evaluator : Pointer_To_IDANumber;
      Free      : Boolean := True)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector3BSpline
         (Pointer (This),
          degree,
          knots,
          ctrlPts,
          weights,
          evaluator,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (knots);
               GNATCOM.Interface.Free (ctrlPts);
               GNATCOM.Interface.Free (weights);
      
      end if;

      return RetVal;
   end Vector3BSpline;

    function Pow
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Pow
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Pow;

    function uAbs
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uAbs
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end uAbs;

    function Sqrt
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Sqrt
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Sqrt;

    function Floor
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Floor
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Floor;

    function Round
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Round
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Round;

    function Ceiling
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Ceiling
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Ceiling;

    function Asin
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Asin
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Asin;

    function Acos
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Acos
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Acos;

    function Atan
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Atan
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Atan;

    function Sin
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Sin
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Sin;

    function Cos
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Cos
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Cos;

    function Tan
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Tan
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Tan;

    function Exp
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Exp
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Exp;

    function Ln
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Ln
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Ln;

    function Log10
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Log10
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Log10;

    function ToDegrees
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ToDegrees
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ToDegrees;

    function ToRadians
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ToRadians
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ToRadians;

    function uMod
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uMod
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end uMod;

    function Atan2
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Atan2
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Atan2;

    function Add
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Add
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Add;

    function Sub
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Sub
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Sub;

    function Mul
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Mul
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Mul;

    function Div
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Div
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Div;

    function LT
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LT
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end LT;

    function LTE
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LTE
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end LTE;

    function GT
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GT
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end GT;

    function GTE
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GTE
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end GTE;

    function EQ
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.EQ
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end EQ;

    function NE
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NE
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end NE;

    function Neg
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Neg
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Neg;

    function InterpolateAnim
     (This       : IDAStatics_Type;
      from_0     : Pointer_To_IDANumber;
      to_1       : Pointer_To_IDANumber;
      duration_2 : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.InterpolateAnim
         (Pointer (This),
          from_0,
          to_1,
          duration_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end InterpolateAnim;

    function Interpolate
     (This       : IDAStatics_Type;
      from_0     : Interfaces.C.double;
      to_1       : Interfaces.C.double;
      duration_2 : Interfaces.C.double)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Interpolate
         (Pointer (This),
          from_0,
          to_1,
          duration_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Interpolate;

    function SlowInSlowOutAnim
     (This        : IDAStatics_Type;
      from_0      : Pointer_To_IDANumber;
      to_1        : Pointer_To_IDANumber;
      duration_2  : Pointer_To_IDANumber;
      sharpness_3 : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SlowInSlowOutAnim
         (Pointer (This),
          from_0,
          to_1,
          duration_2,
          sharpness_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end SlowInSlowOutAnim;

    function SlowInSlowOut
     (This        : IDAStatics_Type;
      from_0      : Interfaces.C.double;
      to_1        : Interfaces.C.double;
      duration_2  : Interfaces.C.double;
      sharpness_3 : Interfaces.C.double)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SlowInSlowOut
         (Pointer (This),
          from_0,
          to_1,
          duration_2,
          sharpness_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end SlowInSlowOut;

    function SoundSource
     (This  : IDAStatics_Type;
      snd_0 : Pointer_To_IDASound)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SoundSource
         (Pointer (This),
          snd_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end SoundSource;

    function Mix
     (This    : IDAStatics_Type;
      left_0  : Pointer_To_IDASound;
      right_1 : Pointer_To_IDASound)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Mix
         (Pointer (This),
          left_0,
          right_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Mix;

    function uAnd
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDABoolean;
      b_1   : Pointer_To_IDABoolean)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uAnd
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end uAnd;

    function uOr
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDABoolean;
      b_1   : Pointer_To_IDABoolean)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uOr
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end uOr;

    function uNot
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDABoolean)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uNot
         (Pointer (This),
          a_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end uNot;

    function Integral
     (This  : IDAStatics_Type;
      b_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Integral
         (Pointer (This),
          b_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Integral;

    function Derivative
     (This  : IDAStatics_Type;
      b_0   : Pointer_To_IDANumber)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Derivative
         (Pointer (This),
          b_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Derivative;

    function IntegralVector2
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector2)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IntegralVector2
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end IntegralVector2;

    function IntegralVector3
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IntegralVector3
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end IntegralVector3;

    function DerivativeVector2
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector2)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DerivativeVector2
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DerivativeVector2;

    function DerivativeVector3
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DerivativeVector3
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DerivativeVector3;

    function DerivativePoint2
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAPoint2)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DerivativePoint2
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DerivativePoint2;

    function DerivativePoint3
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAPoint3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DerivativePoint3
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DerivativePoint3;

    function KeyState
     (This  : IDAStatics_Type;
      n_0   : Pointer_To_IDANumber)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.KeyState
         (Pointer (This),
          n_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end KeyState;

    function KeyUp
     (This  : IDAStatics_Type;
      arg_0 : Interfaces.C.long)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.KeyUp
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end KeyUp;

    function KeyDown
     (This  : IDAStatics_Type;
      arg_0 : Interfaces.C.long)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.KeyDown
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end KeyDown;

    function DANumber
     (This  : IDAStatics_Type;
      num_0 : Interfaces.C.double)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DANumber
         (Pointer (This),
          num_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DANumber;

    function DAString
     (This  : IDAStatics_Type;
      str_0 : GNATCOM.Types.BSTR;
      Free  : Boolean := True)
     return Pointer_To_IDAString
   is
       RetVal : aliased Pointer_To_IDAString;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DAString
         (Pointer (This),
          str_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (str_0);
      
      end if;

      return RetVal;
   end DAString;

    function DABoolean
     (This  : IDAStatics_Type;
      num_0 : GNATCOM.Types.VARIANT_BOOL)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DABoolean
         (Pointer (This),
          num_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DABoolean;

    function SeededRandom
     (This  : IDAStatics_Type;
      arg_0 : Interfaces.C.double)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SeededRandom
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end SeededRandom;

    function Get_MousePosition
     (This  : IDAStatics_Type)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_MousePosition
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_MousePosition;

    function Get_LeftButtonState
     (This  : IDAStatics_Type)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_LeftButtonState
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_LeftButtonState;

    function Get_RightButtonState
     (This  : IDAStatics_Type)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_RightButtonState
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_RightButtonState;

    function Get_DATrue
     (This  : IDAStatics_Type)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DATrue
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DATrue;

    function Get_DAFalse
     (This  : IDAStatics_Type)
     return Pointer_To_IDABoolean
   is
       RetVal : aliased Pointer_To_IDABoolean;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DAFalse
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DAFalse;

    function Get_LocalTime
     (This  : IDAStatics_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_LocalTime
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_LocalTime;

    function Get_GlobalTime
     (This  : IDAStatics_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_GlobalTime
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_GlobalTime;

    function Get_Pixel
     (This  : IDAStatics_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Pixel
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Pixel;

    function UserData
     (This   : IDAStatics_Type;
      data_0 : GNATCOM.Types.Pointer_To_IUnknown)
     return Pointer_To_IDAUserData
   is
       RetVal : aliased Pointer_To_IDAUserData;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UserData
         (Pointer (This),
          data_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end UserData;

    function UntilNotify
     (This       : IDAStatics_Type;
      b0_0       : Pointer_To_IDABehavior;
      event_1    : Pointer_To_IDAEvent;
      notifier_2 : Pointer_To_IDAUntilNotifier)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UntilNotify
         (Pointer (This),
          b0_0,
          event_1,
          notifier_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end UntilNotify;

    function uUntil
     (This    : IDAStatics_Type;
      b0_0    : Pointer_To_IDABehavior;
      event_1 : Pointer_To_IDAEvent;
      b1_2    : Pointer_To_IDABehavior)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uUntil
         (Pointer (This),
          b0_0,
          event_1,
          b1_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end uUntil;

    function UntilEx
     (This    : IDAStatics_Type;
      b0_0    : Pointer_To_IDABehavior;
      event_1 : Pointer_To_IDAEvent)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UntilEx
         (Pointer (This),
          b0_0,
          event_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end UntilEx;

    function Sequence
     (This  : IDAStatics_Type;
      s1_0  : Pointer_To_IDABehavior;
      s2_1  : Pointer_To_IDABehavior)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Sequence
         (Pointer (This),
          s1_0,
          s2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Sequence;

    function FollowPath
     (This       : IDAStatics_Type;
      path_0     : Pointer_To_IDAPath2;
      duration_1 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPath
         (Pointer (This),
          path_0,
          duration_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPath;

    function FollowPathAngle
     (This       : IDAStatics_Type;
      path_0     : Pointer_To_IDAPath2;
      duration_1 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathAngle
         (Pointer (This),
          path_0,
          duration_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathAngle;

    function FollowPathAngleUpright
     (This       : IDAStatics_Type;
      path_0     : Pointer_To_IDAPath2;
      duration_1 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathAngleUpright
         (Pointer (This),
          path_0,
          duration_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathAngleUpright;

    function FollowPathEval
     (This   : IDAStatics_Type;
      path_0 : Pointer_To_IDAPath2;
      eval_1 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathEval
         (Pointer (This),
          path_0,
          eval_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathEval;

    function FollowPathAngleEval
     (This   : IDAStatics_Type;
      path_0 : Pointer_To_IDAPath2;
      eval_1 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathAngleEval
         (Pointer (This),
          path_0,
          eval_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathAngleEval;

    function FollowPathAngleUprightEval
     (This   : IDAStatics_Type;
      path_0 : Pointer_To_IDAPath2;
      eval_1 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathAngleUprightEval
         (Pointer (This),
          path_0,
          eval_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathAngleUprightEval;

    function FollowPathAnim
     (This         : IDAStatics_Type;
      obsoleted1_0 : Pointer_To_IDAPath2;
      obsoleted2_1 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathAnim
         (Pointer (This),
          obsoleted1_0,
          obsoleted2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathAnim;

    function FollowPathAngleAnim
     (This         : IDAStatics_Type;
      obsoleted1_0 : Pointer_To_IDAPath2;
      obsoleted2_1 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathAngleAnim
         (Pointer (This),
          obsoleted1_0,
          obsoleted2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathAngleAnim;

    function FollowPathAngleUprightAnim
     (This         : IDAStatics_Type;
      obsoleted1_0 : Pointer_To_IDAPath2;
      obsoleted2_1 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FollowPathAngleUprightAnim
         (Pointer (This),
          obsoleted1_0,
          obsoleted2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end FollowPathAngleUprightAnim;

    function ConcatString
     (This  : IDAStatics_Type;
      s1_0  : Pointer_To_IDAString;
      s2_1  : Pointer_To_IDAString)
     return Pointer_To_IDAString
   is
       RetVal : aliased Pointer_To_IDAString;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ConcatString
         (Pointer (This),
          s1_0,
          s2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ConcatString;

    function PerspectiveCamera
     (This        : IDAStatics_Type;
      focalDist_0 : Interfaces.C.double;
      nearClip_1  : Interfaces.C.double)
     return Pointer_To_IDACamera
   is
       RetVal : aliased Pointer_To_IDACamera;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PerspectiveCamera
         (Pointer (This),
          focalDist_0,
          nearClip_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end PerspectiveCamera;

    function PerspectiveCameraAnim
     (This        : IDAStatics_Type;
      focalDist_0 : Pointer_To_IDANumber;
      nearClip_1  : Pointer_To_IDANumber)
     return Pointer_To_IDACamera
   is
       RetVal : aliased Pointer_To_IDACamera;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PerspectiveCameraAnim
         (Pointer (This),
          focalDist_0,
          nearClip_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end PerspectiveCameraAnim;

    function ParallelCamera
     (This       : IDAStatics_Type;
      nearClip_0 : Interfaces.C.double)
     return Pointer_To_IDACamera
   is
       RetVal : aliased Pointer_To_IDACamera;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ParallelCamera
         (Pointer (This),
          nearClip_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ParallelCamera;

    function ParallelCameraAnim
     (This       : IDAStatics_Type;
      nearClip_0 : Pointer_To_IDANumber)
     return Pointer_To_IDACamera
   is
       RetVal : aliased Pointer_To_IDACamera;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ParallelCameraAnim
         (Pointer (This),
          nearClip_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ParallelCameraAnim;

    function ColorRgbAnim
     (This    : IDAStatics_Type;
      red_0   : Pointer_To_IDANumber;
      green_1 : Pointer_To_IDANumber;
      blue_2  : Pointer_To_IDANumber)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ColorRgbAnim
         (Pointer (This),
          red_0,
          green_1,
          blue_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end ColorRgbAnim;

    function ColorRgb
     (This    : IDAStatics_Type;
      red_0   : Interfaces.C.double;
      green_1 : Interfaces.C.double;
      blue_2  : Interfaces.C.double)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ColorRgb
         (Pointer (This),
          red_0,
          green_1,
          blue_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end ColorRgb;

    function ColorRgb255
     (This    : IDAStatics_Type;
      red_0   : Interfaces.C.short;
      green_1 : Interfaces.C.short;
      blue_2  : Interfaces.C.short)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ColorRgb255
         (Pointer (This),
          red_0,
          green_1,
          blue_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end ColorRgb255;

    function ColorHsl
     (This         : IDAStatics_Type;
      hue_0        : Interfaces.C.double;
      saturation_1 : Interfaces.C.double;
      lum_2        : Interfaces.C.double)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ColorHsl
         (Pointer (This),
          hue_0,
          saturation_1,
          lum_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end ColorHsl;

    function ColorHslAnim
     (This         : IDAStatics_Type;
      hue_0        : Pointer_To_IDANumber;
      saturation_1 : Pointer_To_IDANumber;
      lum_2        : Pointer_To_IDANumber)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ColorHslAnim
         (Pointer (This),
          hue_0,
          saturation_1,
          lum_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end ColorHslAnim;

    function Get_Red
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Red
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Red;

    function Get_Green
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Green
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Green;

    function Get_Blue
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Blue
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Blue;

    function Get_Cyan
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Cyan
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Cyan;

    function Get_Magenta
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Magenta
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Magenta;

    function Get_Yellow
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Yellow
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Yellow;

    function Get_Black
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Black
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Black;

    function Get_White
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_White
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_White;

    function Get_Aqua
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Aqua
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Aqua;

    function Get_Fuchsia
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Fuchsia
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Fuchsia;

    function Get_Gray
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Gray
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Gray;

    function Get_Lime
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Lime
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Lime;

    function Get_Maroon
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Maroon
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Maroon;

    function Get_Navy
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Navy
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Navy;

    function Get_Olive
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Olive
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Olive;

    function Get_Purple
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Purple
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Purple;

    function Get_Silver
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Silver
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Silver;

    function Get_Teal
     (This  : IDAStatics_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Teal
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Teal;

    function Predicate
     (This  : IDAStatics_Type;
      b_0   : Pointer_To_IDABoolean)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Predicate
         (Pointer (This),
          b_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Predicate;

    function NotEvent
     (This    : IDAStatics_Type;
      event_0 : Pointer_To_IDAEvent)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NotEvent
         (Pointer (This),
          event_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end NotEvent;

    function AndEvent
     (This  : IDAStatics_Type;
      e1_0  : Pointer_To_IDAEvent;
      e2_1  : Pointer_To_IDAEvent)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AndEvent
         (Pointer (This),
          e1_0,
          e2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end AndEvent;

    function OrEvent
     (This  : IDAStatics_Type;
      e1_0  : Pointer_To_IDAEvent;
      e2_1  : Pointer_To_IDAEvent)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OrEvent
         (Pointer (This),
          e1_0,
          e2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end OrEvent;

    function ThenEvent
     (This  : IDAStatics_Type;
      e1_0  : Pointer_To_IDAEvent;
      e2_1  : Pointer_To_IDAEvent)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ThenEvent
         (Pointer (This),
          e1_0,
          e2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ThenEvent;

    function Get_LeftButtonDown
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_LeftButtonDown
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_LeftButtonDown;

    function Get_LeftButtonUp
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_LeftButtonUp
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_LeftButtonUp;

    function Get_RightButtonDown
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_RightButtonDown
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_RightButtonDown;

    function Get_RightButtonUp
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_RightButtonUp
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_RightButtonUp;

    function Get_Always
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Always
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Always;

    function Get_Never
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Never
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Never;

    function TimerAnim
     (This  : IDAStatics_Type;
      n_0   : Pointer_To_IDANumber)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TimerAnim
         (Pointer (This),
          n_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end TimerAnim;

    function Timer
     (This  : IDAStatics_Type;
      n_0   : Interfaces.C.double)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Timer
         (Pointer (This),
          n_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Timer;

    function AppTriggeredEvent
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AppTriggeredEvent
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end AppTriggeredEvent;

    function ScriptCallback
     (This        : IDAStatics_Type;
      obsolete1_0 : GNATCOM.Types.BSTR;
      obsolete2_1 : Pointer_To_IDAEvent;
      obsolete3_2 : GNATCOM.Types.BSTR;
      Free        : Boolean := True)
     return Pointer_To_IDAEvent
   is
       RetVal : aliased Pointer_To_IDAEvent;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ScriptCallback
         (Pointer (This),
          obsolete1_0,
          obsolete2_1,
          obsolete3_2,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (obsolete1_0);
               GNATCOM.Interface.Free (obsolete3_2);
      
      end if;

      return RetVal;
   end ScriptCallback;

    function Get_EmptyGeometry
     (This  : IDAStatics_Type)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_EmptyGeometry
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_EmptyGeometry;

    function UnionGeometry
     (This  : IDAStatics_Type;
      g1_0  : Pointer_To_IDAGeometry;
      g2_1  : Pointer_To_IDAGeometry)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UnionGeometry
         (Pointer (This),
          g1_0,
          g2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end UnionGeometry;

    function UnionGeometryArrayEx
     (This       : IDAStatics_Type;
      imgs_0size : Interfaces.C.long;
      imgs_0     : Pointer_To_Pointer_To_IDAGeometry)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UnionGeometryArrayEx
         (Pointer (This),
          imgs_0size,
          imgs_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end UnionGeometryArrayEx;

    function UnionGeometryArray
     (This   : IDAStatics_Type;
      imgs_0 : GNATCOM.Types.VARIANT;
      Free   : Boolean := True)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UnionGeometryArray
         (Pointer (This),
          imgs_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (imgs_0);
      
      end if;

      return RetVal;
   end UnionGeometryArray;

    function Get_EmptyImage
     (This  : IDAStatics_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_EmptyImage
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_EmptyImage;

    function Get_DetectableEmptyImage
     (This  : IDAStatics_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DetectableEmptyImage
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DetectableEmptyImage;

    function SolidColorImage
     (This  : IDAStatics_Type;
      col_0 : Pointer_To_IDAColor)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SolidColorImage
         (Pointer (This),
          col_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end SolidColorImage;

    function GradientPolygonEx
     (This         : IDAStatics_Type;
      points_0size : Interfaces.C.long;
      points_0     : Pointer_To_Pointer_To_IDAPoint2;
      colors_1size : Interfaces.C.long;
      colors_1     : Pointer_To_Pointer_To_IDAColor)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientPolygonEx
         (Pointer (This),
          points_0size,
          points_0,
          colors_1size,
          colors_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end GradientPolygonEx;

    function GradientPolygon
     (This     : IDAStatics_Type;
      points_0 : GNATCOM.Types.VARIANT;
      colors_1 : GNATCOM.Types.VARIANT;
      Free     : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientPolygon
         (Pointer (This),
          points_0,
          colors_1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (points_0);
               GNATCOM.Interface.Free (colors_1);
      
      end if;

      return RetVal;
   end GradientPolygon;

    function RadialGradientPolygonEx
     (This         : IDAStatics_Type;
      inner_0      : Pointer_To_IDAColor;
      outer_1      : Pointer_To_IDAColor;
      points_2size : Interfaces.C.long;
      points_2     : Pointer_To_Pointer_To_IDAPoint2;
      fallOff_3    : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientPolygonEx
         (Pointer (This),
          inner_0,
          outer_1,
          points_2size,
          points_2,
          fallOff_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end RadialGradientPolygonEx;

    function RadialGradientPolygon
     (This      : IDAStatics_Type;
      inner_0   : Pointer_To_IDAColor;
      outer_1   : Pointer_To_IDAColor;
      points_2  : GNATCOM.Types.VARIANT;
      fallOff_3 : Interfaces.C.double;
      Free      : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientPolygon
         (Pointer (This),
          inner_0,
          outer_1,
          points_2,
          fallOff_3,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (points_2);
      
      end if;

      return RetVal;
   end RadialGradientPolygon;

    function RadialGradientPolygonAnimEx
     (This         : IDAStatics_Type;
      inner_0      : Pointer_To_IDAColor;
      outer_1      : Pointer_To_IDAColor;
      points_2size : Interfaces.C.long;
      points_2     : Pointer_To_Pointer_To_IDAPoint2;
      fallOff_3    : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientPolygonAnimEx
         (Pointer (This),
          inner_0,
          outer_1,
          points_2size,
          points_2,
          fallOff_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end RadialGradientPolygonAnimEx;

    function RadialGradientPolygonAnim
     (This      : IDAStatics_Type;
      inner_0   : Pointer_To_IDAColor;
      outer_1   : Pointer_To_IDAColor;
      points_2  : GNATCOM.Types.VARIANT;
      fallOff_3 : Pointer_To_IDANumber;
      Free      : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientPolygonAnim
         (Pointer (This),
          inner_0,
          outer_1,
          points_2,
          fallOff_3,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (points_2);
      
      end if;

      return RetVal;
   end RadialGradientPolygonAnim;

    function GradientSquare
     (This         : IDAStatics_Type;
      lowerLeft_0  : Pointer_To_IDAColor;
      upperLeft_1  : Pointer_To_IDAColor;
      upperRight_2 : Pointer_To_IDAColor;
      lowerRight_3 : Pointer_To_IDAColor)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientSquare
         (Pointer (This),
          lowerLeft_0,
          upperLeft_1,
          upperRight_2,
          lowerRight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end GradientSquare;

    function RadialGradientSquare
     (This      : IDAStatics_Type;
      inner_0   : Pointer_To_IDAColor;
      outer_1   : Pointer_To_IDAColor;
      fallOff_2 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientSquare
         (Pointer (This),
          inner_0,
          outer_1,
          fallOff_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end RadialGradientSquare;

    function RadialGradientSquareAnim
     (This      : IDAStatics_Type;
      inner_0   : Pointer_To_IDAColor;
      outer_1   : Pointer_To_IDAColor;
      fallOff_2 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientSquareAnim
         (Pointer (This),
          inner_0,
          outer_1,
          fallOff_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end RadialGradientSquareAnim;

    function RadialGradientRegularPoly
     (This       : IDAStatics_Type;
      inner_0    : Pointer_To_IDAColor;
      outer_1    : Pointer_To_IDAColor;
      numEdges_2 : Interfaces.C.double;
      fallOff_3  : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientRegularPoly
         (Pointer (This),
          inner_0,
          outer_1,
          numEdges_2,
          fallOff_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end RadialGradientRegularPoly;

    function RadialGradientRegularPolyAnim
     (This       : IDAStatics_Type;
      inner_0    : Pointer_To_IDAColor;
      outer_1    : Pointer_To_IDAColor;
      numEdges_2 : Pointer_To_IDANumber;
      fallOff_3  : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RadialGradientRegularPolyAnim
         (Pointer (This),
          inner_0,
          outer_1,
          numEdges_2,
          fallOff_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end RadialGradientRegularPolyAnim;

    function GradientHorizontal
     (This      : IDAStatics_Type;
      start_0   : Pointer_To_IDAColor;
      stop_1    : Pointer_To_IDAColor;
      fallOff_2 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientHorizontal
         (Pointer (This),
          start_0,
          stop_1,
          fallOff_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end GradientHorizontal;

    function GradientHorizontalAnim
     (This      : IDAStatics_Type;
      start_0   : Pointer_To_IDAColor;
      stop_1    : Pointer_To_IDAColor;
      fallOff_2 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GradientHorizontalAnim
         (Pointer (This),
          start_0,
          stop_1,
          fallOff_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end GradientHorizontalAnim;

    function HatchHorizontal
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchHorizontal
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchHorizontal;

    function HatchHorizontalAnim
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchHorizontalAnim
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchHorizontalAnim;

    function HatchVertical
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchVertical
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchVertical;

    function HatchVerticalAnim
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchVerticalAnim
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchVerticalAnim;

    function HatchForwardDiagonal
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchForwardDiagonal
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchForwardDiagonal;

    function HatchForwardDiagonalAnim
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchForwardDiagonalAnim
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchForwardDiagonalAnim;

    function HatchBackwardDiagonal
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchBackwardDiagonal
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchBackwardDiagonal;

    function HatchBackwardDiagonalAnim
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchBackwardDiagonalAnim
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchBackwardDiagonalAnim;

    function HatchCross
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchCross
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchCross;

    function HatchCrossAnim
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchCrossAnim
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchCrossAnim;

    function HatchDiagonalCross
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Interfaces.C.double)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchDiagonalCross
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchDiagonalCross;

    function HatchDiagonalCrossAnim
     (This      : IDAStatics_Type;
      lineClr_0 : Pointer_To_IDAColor;
      spacing_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.HatchDiagonalCrossAnim
         (Pointer (This),
          lineClr_0,
          spacing_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end HatchDiagonalCrossAnim;

    function Overlay
     (This     : IDAStatics_Type;
      top_0    : Pointer_To_IDAImage;
      bottom_1 : Pointer_To_IDAImage)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Overlay
         (Pointer (This),
          top_0,
          bottom_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Overlay;

    function OverlayArrayEx
     (This       : IDAStatics_Type;
      imgs_0size : Interfaces.C.long;
      imgs_0     : Pointer_To_Pointer_To_IDAImage)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OverlayArrayEx
         (Pointer (This),
          imgs_0size,
          imgs_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end OverlayArrayEx;

    function OverlayArray
     (This   : IDAStatics_Type;
      imgs_0 : GNATCOM.Types.VARIANT;
      Free   : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OverlayArray
         (Pointer (This),
          imgs_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (imgs_0);
      
      end if;

      return RetVal;
   end OverlayArray;

    function Get_AmbientLight
     (This  : IDAStatics_Type)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_AmbientLight
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_AmbientLight;

    function Get_DirectionalLight
     (This  : IDAStatics_Type)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DirectionalLight
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DirectionalLight;

    function Get_PointLight
     (This  : IDAStatics_Type)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PointLight
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PointLight;

    function SpotLightAnim
     (This       : IDAStatics_Type;
      fullcone_0 : Pointer_To_IDANumber;
      cutoff_1   : Pointer_To_IDANumber)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SpotLightAnim
         (Pointer (This),
          fullcone_0,
          cutoff_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SpotLightAnim;

    function SpotLight
     (This       : IDAStatics_Type;
      fullcone_0 : Pointer_To_IDANumber;
      cutoff_1   : Interfaces.C.double)
     return Pointer_To_IDAGeometry
   is
       RetVal : aliased Pointer_To_IDAGeometry;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SpotLight
         (Pointer (This),
          fullcone_0,
          cutoff_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SpotLight;

    function Get_DefaultLineStyle
     (This  : IDAStatics_Type)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DefaultLineStyle
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DefaultLineStyle;

    function Get_EmptyLineStyle
     (This  : IDAStatics_Type)
     return Pointer_To_IDALineStyle
   is
       RetVal : aliased Pointer_To_IDALineStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_EmptyLineStyle
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_EmptyLineStyle;

    function Get_JoinStyleBevel
     (This  : IDAStatics_Type)
     return Pointer_To_IDAJoinStyle
   is
       RetVal : aliased Pointer_To_IDAJoinStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_JoinStyleBevel
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_JoinStyleBevel;

    function Get_JoinStyleRound
     (This  : IDAStatics_Type)
     return Pointer_To_IDAJoinStyle
   is
       RetVal : aliased Pointer_To_IDAJoinStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_JoinStyleRound
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_JoinStyleRound;

    function Get_JoinStyleMiter
     (This  : IDAStatics_Type)
     return Pointer_To_IDAJoinStyle
   is
       RetVal : aliased Pointer_To_IDAJoinStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_JoinStyleMiter
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_JoinStyleMiter;

    function Get_EndStyleFlat
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEndStyle
   is
       RetVal : aliased Pointer_To_IDAEndStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_EndStyleFlat
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_EndStyleFlat;

    function Get_EndStyleSquare
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEndStyle
   is
       RetVal : aliased Pointer_To_IDAEndStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_EndStyleSquare
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_EndStyleSquare;

    function Get_EndStyleRound
     (This  : IDAStatics_Type)
     return Pointer_To_IDAEndStyle
   is
       RetVal : aliased Pointer_To_IDAEndStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_EndStyleRound
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_EndStyleRound;

    function Get_DashStyleSolid
     (This  : IDAStatics_Type)
     return Pointer_To_IDADashStyle
   is
       RetVal : aliased Pointer_To_IDADashStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DashStyleSolid
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DashStyleSolid;

    function Get_DashStyleDashed
     (This  : IDAStatics_Type)
     return Pointer_To_IDADashStyle
   is
       RetVal : aliased Pointer_To_IDADashStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DashStyleDashed
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DashStyleDashed;

    function Get_DefaultMicrophone
     (This  : IDAStatics_Type)
     return Pointer_To_IDAMicrophone
   is
       RetVal : aliased Pointer_To_IDAMicrophone;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DefaultMicrophone
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DefaultMicrophone;

    function Get_OpaqueMatte
     (This  : IDAStatics_Type)
     return Pointer_To_IDAMatte
   is
       RetVal : aliased Pointer_To_IDAMatte;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_OpaqueMatte
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_OpaqueMatte;

    function Get_ClearMatte
     (This  : IDAStatics_Type)
     return Pointer_To_IDAMatte
   is
       RetVal : aliased Pointer_To_IDAMatte;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ClearMatte
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ClearMatte;

    function UnionMatte
     (This  : IDAStatics_Type;
      m1_0  : Pointer_To_IDAMatte;
      m2_1  : Pointer_To_IDAMatte)
     return Pointer_To_IDAMatte
   is
       RetVal : aliased Pointer_To_IDAMatte;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UnionMatte
         (Pointer (This),
          m1_0,
          m2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end UnionMatte;

    function IntersectMatte
     (This  : IDAStatics_Type;
      m1_0  : Pointer_To_IDAMatte;
      m2_1  : Pointer_To_IDAMatte)
     return Pointer_To_IDAMatte
   is
       RetVal : aliased Pointer_To_IDAMatte;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IntersectMatte
         (Pointer (This),
          m1_0,
          m2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end IntersectMatte;

    function DifferenceMatte
     (This  : IDAStatics_Type;
      m1_0  : Pointer_To_IDAMatte;
      m2_1  : Pointer_To_IDAMatte)
     return Pointer_To_IDAMatte
   is
       RetVal : aliased Pointer_To_IDAMatte;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DifferenceMatte
         (Pointer (This),
          m1_0,
          m2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end DifferenceMatte;

    function FillMatte
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPath2)
     return Pointer_To_IDAMatte
   is
       RetVal : aliased Pointer_To_IDAMatte;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FillMatte
         (Pointer (This),
          p_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end FillMatte;

    function TextMatte
     (This  : IDAStatics_Type;
      str_0 : Pointer_To_IDAString;
      fs_1  : Pointer_To_IDAFontStyle)
     return Pointer_To_IDAMatte
   is
       RetVal : aliased Pointer_To_IDAMatte;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TextMatte
         (Pointer (This),
          str_0,
          fs_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end TextMatte;

    function Get_EmptyMontage
     (This  : IDAStatics_Type)
     return Pointer_To_IDAMontage
   is
       RetVal : aliased Pointer_To_IDAMontage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_EmptyMontage
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_EmptyMontage;

    function ImageMontage
     (This    : IDAStatics_Type;
      im_0    : Pointer_To_IDAImage;
      depth_1 : Interfaces.C.double)
     return Pointer_To_IDAMontage
   is
       RetVal : aliased Pointer_To_IDAMontage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImageMontage
         (Pointer (This),
          im_0,
          depth_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ImageMontage;

    function ImageMontageAnim
     (This    : IDAStatics_Type;
      im_0    : Pointer_To_IDAImage;
      depth_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAMontage
   is
       RetVal : aliased Pointer_To_IDAMontage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ImageMontageAnim
         (Pointer (This),
          im_0,
          depth_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ImageMontageAnim;

    function UnionMontage
     (This  : IDAStatics_Type;
      m1_0  : Pointer_To_IDAMontage;
      m2_1  : Pointer_To_IDAMontage)
     return Pointer_To_IDAMontage
   is
       RetVal : aliased Pointer_To_IDAMontage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.UnionMontage
         (Pointer (This),
          m1_0,
          m2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end UnionMontage;

    function Concat
     (This  : IDAStatics_Type;
      p1_0  : Pointer_To_IDAPath2;
      p2_1  : Pointer_To_IDAPath2)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Concat
         (Pointer (This),
          p1_0,
          p2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Concat;

    function ConcatArrayEx
     (This        : IDAStatics_Type;
      paths_0size : Interfaces.C.long;
      paths_0     : Pointer_To_Pointer_To_IDAPath2)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ConcatArrayEx
         (Pointer (This),
          paths_0size,
          paths_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end ConcatArrayEx;

    function ConcatArray
     (This    : IDAStatics_Type;
      paths_0 : GNATCOM.Types.VARIANT;
      Free    : Boolean := True)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ConcatArray
         (Pointer (This),
          paths_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (paths_0);
      
      end if;

      return RetVal;
   end ConcatArray;

    function Line
     (This  : IDAStatics_Type;
      p1_0  : Pointer_To_IDAPoint2;
      p2_1  : Pointer_To_IDAPoint2)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Line
         (Pointer (This),
          p1_0,
          p2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Line;

    function Ray
     (This  : IDAStatics_Type;
      pt_0  : Pointer_To_IDAPoint2)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Ray
         (Pointer (This),
          pt_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Ray;

    function StringPathAnim
     (This  : IDAStatics_Type;
      str_0 : Pointer_To_IDAString;
      fs_1  : Pointer_To_IDAFontStyle)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.StringPathAnim
         (Pointer (This),
          str_0,
          fs_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end StringPathAnim;

    function StringPath
     (This  : IDAStatics_Type;
      str_0 : GNATCOM.Types.BSTR;
      fs_1  : Pointer_To_IDAFontStyle;
      Free  : Boolean := True)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.StringPath
         (Pointer (This),
          str_0,
          fs_1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (str_0);
      
      end if;

      return RetVal;
   end StringPath;

    function PolylineEx
     (This         : IDAStatics_Type;
      points_0size : Interfaces.C.long;
      points_0     : Pointer_To_Pointer_To_IDAPoint2)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PolylineEx
         (Pointer (This),
          points_0size,
          points_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end PolylineEx;

    function Polyline
     (This     : IDAStatics_Type;
      points_0 : GNATCOM.Types.VARIANT;
      Free     : Boolean := True)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Polyline
         (Pointer (This),
          points_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (points_0);
      
      end if;

      return RetVal;
   end Polyline;

    function PolydrawPathEx
     (This         : IDAStatics_Type;
      points_0size : Interfaces.C.long;
      points_0     : Pointer_To_Pointer_To_IDAPoint2;
      codes_1size  : Interfaces.C.long;
      codes_1      : Pointer_To_Pointer_To_IDANumber)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PolydrawPathEx
         (Pointer (This),
          points_0size,
          points_0,
          codes_1size,
          codes_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end PolydrawPathEx;

    function PolydrawPath
     (This     : IDAStatics_Type;
      points_0 : GNATCOM.Types.VARIANT;
      codes_1  : GNATCOM.Types.VARIANT;
      Free     : Boolean := True)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PolydrawPath
         (Pointer (This),
          points_0,
          codes_1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (points_0);
               GNATCOM.Interface.Free (codes_1);
      
      end if;

      return RetVal;
   end PolydrawPath;

    function ArcRadians
     (This         : IDAStatics_Type;
      startAngle_0 : Interfaces.C.double;
      endAngle_1   : Interfaces.C.double;
      arcWidth_2   : Interfaces.C.double;
      arcHeight_3  : Interfaces.C.double)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ArcRadians
         (Pointer (This),
          startAngle_0,
          endAngle_1,
          arcWidth_2,
          arcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end ArcRadians;

    function ArcRadiansAnim
     (This         : IDAStatics_Type;
      startAngle_0 : Pointer_To_IDANumber;
      endAngle_1   : Pointer_To_IDANumber;
      arcWidth_2   : Pointer_To_IDANumber;
      arcHeight_3  : Pointer_To_IDANumber)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ArcRadiansAnim
         (Pointer (This),
          startAngle_0,
          endAngle_1,
          arcWidth_2,
          arcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end ArcRadiansAnim;

    function ArcDegrees
     (This         : IDAStatics_Type;
      startAngle_0 : Interfaces.C.double;
      endAngle_1   : Interfaces.C.double;
      arcWidth_2   : Interfaces.C.double;
      arcHeight_3  : Interfaces.C.double)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ArcDegrees
         (Pointer (This),
          startAngle_0,
          endAngle_1,
          arcWidth_2,
          arcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end ArcDegrees;

    function PieRadians
     (This         : IDAStatics_Type;
      startAngle_0 : Interfaces.C.double;
      endAngle_1   : Interfaces.C.double;
      arcWidth_2   : Interfaces.C.double;
      arcHeight_3  : Interfaces.C.double)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PieRadians
         (Pointer (This),
          startAngle_0,
          endAngle_1,
          arcWidth_2,
          arcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end PieRadians;

    function PieRadiansAnim
     (This         : IDAStatics_Type;
      startAngle_0 : Pointer_To_IDANumber;
      endAngle_1   : Pointer_To_IDANumber;
      arcWidth_2   : Pointer_To_IDANumber;
      arcHeight_3  : Pointer_To_IDANumber)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PieRadiansAnim
         (Pointer (This),
          startAngle_0,
          endAngle_1,
          arcWidth_2,
          arcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end PieRadiansAnim;

    function PieDegrees
     (This         : IDAStatics_Type;
      startAngle_0 : Interfaces.C.double;
      endAngle_1   : Interfaces.C.double;
      arcWidth_2   : Interfaces.C.double;
      arcHeight_3  : Interfaces.C.double)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PieDegrees
         (Pointer (This),
          startAngle_0,
          endAngle_1,
          arcWidth_2,
          arcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end PieDegrees;

    function Oval
     (This     : IDAStatics_Type;
      width_0  : Interfaces.C.double;
      height_1 : Interfaces.C.double)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Oval
         (Pointer (This),
          width_0,
          height_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Oval;

    function OvalAnim
     (This     : IDAStatics_Type;
      width_0  : Pointer_To_IDANumber;
      height_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OvalAnim
         (Pointer (This),
          width_0,
          height_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end OvalAnim;

    function Rect
     (This     : IDAStatics_Type;
      width_0  : Interfaces.C.double;
      height_1 : Interfaces.C.double)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rect
         (Pointer (This),
          width_0,
          height_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rect;

    function RectAnim
     (This     : IDAStatics_Type;
      width_0  : Pointer_To_IDANumber;
      height_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RectAnim
         (Pointer (This),
          width_0,
          height_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end RectAnim;

    function RoundRect
     (This              : IDAStatics_Type;
      width_0           : Interfaces.C.double;
      height_1          : Interfaces.C.double;
      cornerArcWidth_2  : Interfaces.C.double;
      cornerArcHeight_3 : Interfaces.C.double)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RoundRect
         (Pointer (This),
          width_0,
          height_1,
          cornerArcWidth_2,
          cornerArcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end RoundRect;

    function RoundRectAnim
     (This              : IDAStatics_Type;
      width_0           : Pointer_To_IDANumber;
      height_1          : Pointer_To_IDANumber;
      cornerArcWidth_2  : Pointer_To_IDANumber;
      cornerArcHeight_3 : Pointer_To_IDANumber)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RoundRectAnim
         (Pointer (This),
          width_0,
          height_1,
          cornerArcWidth_2,
          cornerArcHeight_3,
          RetVal'Unchecked_Access));

      return RetVal;
   end RoundRectAnim;

    function CubicBSplinePathEx
     (This         : IDAStatics_Type;
      points_0size : Interfaces.C.long;
      points_0     : Pointer_To_Pointer_To_IDAPoint2;
      knots_1size  : Interfaces.C.long;
      knots_1      : Pointer_To_Pointer_To_IDANumber)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.CubicBSplinePathEx
         (Pointer (This),
          points_0size,
          points_0,
          knots_1size,
          knots_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end CubicBSplinePathEx;

    function CubicBSplinePath
     (This     : IDAStatics_Type;
      points_0 : GNATCOM.Types.VARIANT;
      knots_1  : GNATCOM.Types.VARIANT;
      Free     : Boolean := True)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.CubicBSplinePath
         (Pointer (This),
          points_0,
          knots_1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (points_0);
               GNATCOM.Interface.Free (knots_1);
      
      end if;

      return RetVal;
   end CubicBSplinePath;

    function TextPath
     (This        : IDAStatics_Type;
      obsolete1_0 : Pointer_To_IDAString;
      obsolete2_1 : Pointer_To_IDAFontStyle)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TextPath
         (Pointer (This),
          obsolete1_0,
          obsolete2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end TextPath;

    function Get_Silence
     (This  : IDAStatics_Type)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Silence
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Silence;

    function MixArrayEx
     (This       : IDAStatics_Type;
      snds_0size : Interfaces.C.long;
      snds_0     : Pointer_To_Pointer_To_IDASound)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.MixArrayEx
         (Pointer (This),
          snds_0size,
          snds_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end MixArrayEx;

    function MixArray
     (This   : IDAStatics_Type;
      snds_0 : GNATCOM.Types.VARIANT;
      Free   : Boolean := True)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.MixArray
         (Pointer (This),
          snds_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (snds_0);
      
      end if;

      return RetVal;
   end MixArray;

    function Get_SinSynth
     (This  : IDAStatics_Type)
     return Pointer_To_IDASound
   is
       RetVal : aliased Pointer_To_IDASound;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SinSynth
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SinSynth;

    function Get_DefaultFont
     (This  : IDAStatics_Type)
     return Pointer_To_IDAFontStyle
   is
       RetVal : aliased Pointer_To_IDAFontStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DefaultFont
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DefaultFont;

    function FontAnim
     (This   : IDAStatics_Type;
      str_0  : Pointer_To_IDAString;
      size_1 : Pointer_To_IDANumber;
      col_2  : Pointer_To_IDAColor)
     return Pointer_To_IDAFontStyle
   is
       RetVal : aliased Pointer_To_IDAFontStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FontAnim
         (Pointer (This),
          str_0,
          size_1,
          col_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end FontAnim;

    function Font
     (This   : IDAStatics_Type;
      str_0  : GNATCOM.Types.BSTR;
      size_1 : Interfaces.C.double;
      col_2  : Pointer_To_IDAColor;
      Free   : Boolean := True)
     return Pointer_To_IDAFontStyle
   is
       RetVal : aliased Pointer_To_IDAFontStyle;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Font
         (Pointer (This),
          str_0,
          size_1,
          col_2,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (str_0);
      
      end if;

      return RetVal;
   end Font;

    function StringImageAnim
     (This  : IDAStatics_Type;
      str_0 : Pointer_To_IDAString;
      fs_1  : Pointer_To_IDAFontStyle)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.StringImageAnim
         (Pointer (This),
          str_0,
          fs_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end StringImageAnim;

    function StringImage
     (This  : IDAStatics_Type;
      str_0 : GNATCOM.Types.BSTR;
      fs_1  : Pointer_To_IDAFontStyle;
      Free  : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.StringImage
         (Pointer (This),
          str_0,
          fs_1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (str_0);
      
      end if;

      return RetVal;
   end StringImage;

    function TextImageAnim
     (This         : IDAStatics_Type;
      obsoleted1_0 : Pointer_To_IDAString;
      obsoleted2_1 : Pointer_To_IDAFontStyle)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TextImageAnim
         (Pointer (This),
          obsoleted1_0,
          obsoleted2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end TextImageAnim;

    function TextImage
     (This         : IDAStatics_Type;
      obsoleted1_0 : GNATCOM.Types.BSTR;
      obsoleted2_1 : Pointer_To_IDAFontStyle;
      Free         : Boolean := True)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.TextImage
         (Pointer (This),
          obsoleted1_0,
          obsoleted2_1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (obsoleted1_0);
      
      end if;

      return RetVal;
   end TextImage;

    function Get_XVector2
     (This  : IDAStatics_Type)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_XVector2
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_XVector2;

    function Get_YVector2
     (This  : IDAStatics_Type)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_YVector2
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_YVector2;

    function Get_ZeroVector2
     (This  : IDAStatics_Type)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ZeroVector2
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ZeroVector2;

    function Get_Origin2
     (This  : IDAStatics_Type)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Origin2
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Origin2;

    function Vector2Anim
     (This  : IDAStatics_Type;
      x_0   : Pointer_To_IDANumber;
      y_1   : Pointer_To_IDANumber)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector2Anim
         (Pointer (This),
          x_0,
          y_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector2Anim;

    function Vector2
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector2
         (Pointer (This),
          x_0,
          y_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector2;

    function Point2Anim
     (This  : IDAStatics_Type;
      x_0   : Pointer_To_IDANumber;
      y_1   : Pointer_To_IDANumber)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point2Anim
         (Pointer (This),
          x_0,
          y_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point2Anim;

    function Point2
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point2
         (Pointer (This),
          x_0,
          y_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point2;

    function Vector2PolarAnim
     (This     : IDAStatics_Type;
      theta_0  : Pointer_To_IDANumber;
      radius_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector2PolarAnim
         (Pointer (This),
          theta_0,
          radius_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector2PolarAnim;

    function Vector2Polar
     (This     : IDAStatics_Type;
      theta_0  : Interfaces.C.double;
      radius_1 : Interfaces.C.double)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector2Polar
         (Pointer (This),
          theta_0,
          radius_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector2Polar;

    function Vector2PolarDegrees
     (This     : IDAStatics_Type;
      theta_0  : Interfaces.C.double;
      radius_1 : Interfaces.C.double)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector2PolarDegrees
         (Pointer (This),
          theta_0,
          radius_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector2PolarDegrees;

    function Point2PolarAnim
     (This     : IDAStatics_Type;
      theta_0  : Pointer_To_IDANumber;
      radius_1 : Pointer_To_IDANumber)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point2PolarAnim
         (Pointer (This),
          theta_0,
          radius_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point2PolarAnim;

    function Point2Polar
     (This     : IDAStatics_Type;
      theta_0  : Interfaces.C.double;
      radius_1 : Interfaces.C.double)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point2Polar
         (Pointer (This),
          theta_0,
          radius_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point2Polar;

    function DotVector2
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector2;
      u_1   : Pointer_To_IDAVector2)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DotVector2
         (Pointer (This),
          v_0,
          u_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end DotVector2;

    function NegVector2
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector2)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NegVector2
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end NegVector2;

    function SubVector2
     (This  : IDAStatics_Type;
      v1_0  : Pointer_To_IDAVector2;
      v2_1  : Pointer_To_IDAVector2)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubVector2
         (Pointer (This),
          v1_0,
          v2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubVector2;

    function AddVector2
     (This  : IDAStatics_Type;
      v1_0  : Pointer_To_IDAVector2;
      v2_1  : Pointer_To_IDAVector2)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddVector2
         (Pointer (This),
          v1_0,
          v2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end AddVector2;

    function AddPoint2Vector
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint2;
      v_1   : Pointer_To_IDAVector2)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddPoint2Vector
         (Pointer (This),
          p_0,
          v_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end AddPoint2Vector;

    function SubPoint2Vector
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint2;
      v_1   : Pointer_To_IDAVector2)
     return Pointer_To_IDAPoint2
   is
       RetVal : aliased Pointer_To_IDAPoint2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubPoint2Vector
         (Pointer (This),
          p_0,
          v_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubPoint2Vector;

    function SubPoint2
     (This  : IDAStatics_Type;
      p1_0  : Pointer_To_IDAPoint2;
      p2_1  : Pointer_To_IDAPoint2)
     return Pointer_To_IDAVector2
   is
       RetVal : aliased Pointer_To_IDAVector2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubPoint2
         (Pointer (This),
          p1_0,
          p2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubPoint2;

    function DistancePoint2
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint2;
      q_1   : Pointer_To_IDAPoint2)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DistancePoint2
         (Pointer (This),
          p_0,
          q_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end DistancePoint2;

    function DistanceSquaredPoint2
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint2;
      q_1   : Pointer_To_IDAPoint2)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DistanceSquaredPoint2
         (Pointer (This),
          p_0,
          q_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end DistanceSquaredPoint2;

    function Get_XVector3
     (This  : IDAStatics_Type)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_XVector3
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_XVector3;

    function Get_YVector3
     (This  : IDAStatics_Type)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_YVector3
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_YVector3;

    function Get_ZVector3
     (This  : IDAStatics_Type)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ZVector3
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ZVector3;

    function Get_ZeroVector3
     (This  : IDAStatics_Type)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ZeroVector3
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ZeroVector3;

    function Get_Origin3
     (This  : IDAStatics_Type)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Origin3
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Origin3;

    function Vector3Anim
     (This  : IDAStatics_Type;
      x_0   : Pointer_To_IDANumber;
      y_1   : Pointer_To_IDANumber;
      z_2   : Pointer_To_IDANumber)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector3Anim
         (Pointer (This),
          x_0,
          y_1,
          z_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector3Anim;

    function Vector3
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double;
      z_2   : Interfaces.C.double)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector3
         (Pointer (This),
          x_0,
          y_1,
          z_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector3;

    function Point3Anim
     (This  : IDAStatics_Type;
      x_0   : Pointer_To_IDANumber;
      y_1   : Pointer_To_IDANumber;
      z_2   : Pointer_To_IDANumber)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point3Anim
         (Pointer (This),
          x_0,
          y_1,
          z_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point3Anim;

    function Point3
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double;
      z_2   : Interfaces.C.double)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point3
         (Pointer (This),
          x_0,
          y_1,
          z_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point3;

    function Vector3SphericalAnim
     (This      : IDAStatics_Type;
      xyAngle_0 : Pointer_To_IDANumber;
      yzAngle_1 : Pointer_To_IDANumber;
      radius_2  : Pointer_To_IDANumber)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector3SphericalAnim
         (Pointer (This),
          xyAngle_0,
          yzAngle_1,
          radius_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector3SphericalAnim;

    function Vector3Spherical
     (This      : IDAStatics_Type;
      xyAngle_0 : Interfaces.C.double;
      yzAngle_1 : Interfaces.C.double;
      radius_2  : Interfaces.C.double)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Vector3Spherical
         (Pointer (This),
          xyAngle_0,
          yzAngle_1,
          radius_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Vector3Spherical;

    function Point3SphericalAnim
     (This      : IDAStatics_Type;
      zxAngle_0 : Pointer_To_IDANumber;
      xyAngle_1 : Pointer_To_IDANumber;
      radius_2  : Pointer_To_IDANumber)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point3SphericalAnim
         (Pointer (This),
          zxAngle_0,
          xyAngle_1,
          radius_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point3SphericalAnim;

    function Point3Spherical
     (This      : IDAStatics_Type;
      zxAngle_0 : Interfaces.C.double;
      xyAngle_1 : Interfaces.C.double;
      radius_2  : Interfaces.C.double)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Point3Spherical
         (Pointer (This),
          zxAngle_0,
          xyAngle_1,
          radius_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Point3Spherical;

    function DotVector3
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector3;
      u_1   : Pointer_To_IDAVector3)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DotVector3
         (Pointer (This),
          v_0,
          u_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end DotVector3;

    function CrossVector3
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector3;
      u_1   : Pointer_To_IDAVector3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.CrossVector3
         (Pointer (This),
          v_0,
          u_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end CrossVector3;

    function NegVector3
     (This  : IDAStatics_Type;
      v_0   : Pointer_To_IDAVector3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.NegVector3
         (Pointer (This),
          v_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end NegVector3;

    function SubVector3
     (This  : IDAStatics_Type;
      v1_0  : Pointer_To_IDAVector3;
      v2_1  : Pointer_To_IDAVector3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubVector3
         (Pointer (This),
          v1_0,
          v2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubVector3;

    function AddVector3
     (This  : IDAStatics_Type;
      v1_0  : Pointer_To_IDAVector3;
      v2_1  : Pointer_To_IDAVector3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddVector3
         (Pointer (This),
          v1_0,
          v2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end AddVector3;

    function AddPoint3Vector
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint3;
      v_1   : Pointer_To_IDAVector3)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddPoint3Vector
         (Pointer (This),
          p_0,
          v_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end AddPoint3Vector;

    function SubPoint3Vector
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint3;
      v_1   : Pointer_To_IDAVector3)
     return Pointer_To_IDAPoint3
   is
       RetVal : aliased Pointer_To_IDAPoint3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubPoint3Vector
         (Pointer (This),
          p_0,
          v_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubPoint3Vector;

    function SubPoint3
     (This  : IDAStatics_Type;
      p1_0  : Pointer_To_IDAPoint3;
      p2_1  : Pointer_To_IDAPoint3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubPoint3
         (Pointer (This),
          p1_0,
          p2_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubPoint3;

    function DistancePoint3
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint3;
      q_1   : Pointer_To_IDAPoint3)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DistancePoint3
         (Pointer (This),
          p_0,
          q_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end DistancePoint3;

    function DistanceSquaredPoint3
     (This  : IDAStatics_Type;
      p_0   : Pointer_To_IDAPoint3;
      q_1   : Pointer_To_IDAPoint3)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DistanceSquaredPoint3
         (Pointer (This),
          p_0,
          q_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end DistanceSquaredPoint3;

    function Get_IdentityTransform3
     (This  : IDAStatics_Type)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_IdentityTransform3
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_IdentityTransform3;

    function Translate3Anim
     (This  : IDAStatics_Type;
      tx_0  : Pointer_To_IDANumber;
      ty_1  : Pointer_To_IDANumber;
      tz_2  : Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate3Anim
         (Pointer (This),
          tx_0,
          ty_1,
          tz_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate3Anim;

    function Translate3
     (This  : IDAStatics_Type;
      tx_0  : Interfaces.C.double;
      ty_1  : Interfaces.C.double;
      tz_2  : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate3
         (Pointer (This),
          tx_0,
          ty_1,
          tz_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate3;

    function Translate3Rate
     (This  : IDAStatics_Type;
      tx_0  : Interfaces.C.double;
      ty_1  : Interfaces.C.double;
      tz_2  : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate3Rate
         (Pointer (This),
          tx_0,
          ty_1,
          tz_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate3Rate;

    function Translate3Vector
     (This    : IDAStatics_Type;
      delta_0 : Pointer_To_IDAVector3)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate3Vector
         (Pointer (This),
          delta_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate3Vector;

    function Translate3Point
     (This         : IDAStatics_Type;
      new_origin_0 : Pointer_To_IDAPoint3)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate3Point
         (Pointer (This),
          new_origin_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate3Point;

    function Scale3Anim
     (This  : IDAStatics_Type;
      x_0   : Pointer_To_IDANumber;
      y_1   : Pointer_To_IDANumber;
      z_2   : Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale3Anim
         (Pointer (This),
          x_0,
          y_1,
          z_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale3Anim;

    function Scale3
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double;
      z_2   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale3
         (Pointer (This),
          x_0,
          y_1,
          z_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale3;

    function Scale3Rate
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double;
      z_2   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale3Rate
         (Pointer (This),
          x_0,
          y_1,
          z_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale3Rate;

    function Scale3Vector
     (This        : IDAStatics_Type;
      scale_vec_0 : Pointer_To_IDAVector3)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale3Vector
         (Pointer (This),
          scale_vec_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale3Vector;

    function Scale3UniformAnim
     (This            : IDAStatics_Type;
      uniform_scale_0 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale3UniformAnim
         (Pointer (This),
          uniform_scale_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale3UniformAnim;

    function Scale3Uniform
     (This            : IDAStatics_Type;
      uniform_scale_0 : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale3Uniform
         (Pointer (This),
          uniform_scale_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale3Uniform;

    function Scale3UniformRate
     (This            : IDAStatics_Type;
      uniform_scale_0 : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale3UniformRate
         (Pointer (This),
          uniform_scale_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale3UniformRate;

    function Rotate3Anim
     (This    : IDAStatics_Type;
      axis_0  : Pointer_To_IDAVector3;
      angle_1 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate3Anim
         (Pointer (This),
          axis_0,
          angle_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate3Anim;

    function Rotate3
     (This    : IDAStatics_Type;
      axis_0  : Pointer_To_IDAVector3;
      angle_1 : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate3
         (Pointer (This),
          axis_0,
          angle_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate3;

    function Rotate3Rate
     (This    : IDAStatics_Type;
      axis_0  : Pointer_To_IDAVector3;
      angle_1 : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate3Rate
         (Pointer (This),
          axis_0,
          angle_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate3Rate;

    function Rotate3Degrees
     (This    : IDAStatics_Type;
      axis_0  : Pointer_To_IDAVector3;
      angle_1 : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate3Degrees
         (Pointer (This),
          axis_0,
          angle_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate3Degrees;

    function Rotate3RateDegrees
     (This    : IDAStatics_Type;
      axis_0  : Pointer_To_IDAVector3;
      angle_1 : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate3RateDegrees
         (Pointer (This),
          axis_0,
          angle_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate3RateDegrees;

    function XShear3Anim
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDANumber;
      b_1   : Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.XShear3Anim
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end XShear3Anim;

    function XShear3
     (This  : IDAStatics_Type;
      a_0   : Interfaces.C.double;
      b_1   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.XShear3
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end XShear3;

    function XShear3Rate
     (This  : IDAStatics_Type;
      a_0   : Interfaces.C.double;
      b_1   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.XShear3Rate
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end XShear3Rate;

    function YShear3Anim
     (This  : IDAStatics_Type;
      c_0   : Pointer_To_IDANumber;
      d_1   : Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.YShear3Anim
         (Pointer (This),
          c_0,
          d_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end YShear3Anim;

    function YShear3
     (This  : IDAStatics_Type;
      c_0   : Interfaces.C.double;
      d_1   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.YShear3
         (Pointer (This),
          c_0,
          d_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end YShear3;

    function YShear3Rate
     (This  : IDAStatics_Type;
      c_0   : Interfaces.C.double;
      d_1   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.YShear3Rate
         (Pointer (This),
          c_0,
          d_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end YShear3Rate;

    function ZShear3Anim
     (This  : IDAStatics_Type;
      e_0   : Pointer_To_IDANumber;
      f_1   : Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ZShear3Anim
         (Pointer (This),
          e_0,
          f_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ZShear3Anim;

    function ZShear3
     (This  : IDAStatics_Type;
      e_0   : Interfaces.C.double;
      f_1   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ZShear3
         (Pointer (This),
          e_0,
          f_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ZShear3;

    function ZShear3Rate
     (This  : IDAStatics_Type;
      e_0   : Interfaces.C.double;
      f_1   : Interfaces.C.double)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.ZShear3Rate
         (Pointer (This),
          e_0,
          f_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end ZShear3Rate;

    function Transform4x4AnimEx
     (This    : IDAStatics_Type;
      m_0size : Interfaces.C.long;
      m_0     : Pointer_To_Pointer_To_IDANumber)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform4x4AnimEx
         (Pointer (This),
          m_0size,
          m_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Transform4x4AnimEx;

    function Transform4x4Anim
     (This  : IDAStatics_Type;
      m_0   : GNATCOM.Types.VARIANT;
      Free  : Boolean := True)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform4x4Anim
         (Pointer (This),
          m_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (m_0);
      
      end if;

      return RetVal;
   end Transform4x4Anim;

    function Compose3
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDATransform3;
      b_1   : Pointer_To_IDATransform3)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Compose3
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Compose3;

    function Compose3ArrayEx
     (This      : IDAStatics_Type;
      xfs_0size : Interfaces.C.long;
      xfs_0     : Pointer_To_Pointer_To_IDATransform3)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Compose3ArrayEx
         (Pointer (This),
          xfs_0size,
          xfs_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Compose3ArrayEx;

    function Compose3Array
     (This  : IDAStatics_Type;
      xfs_0 : GNATCOM.Types.VARIANT;
      Free  : Boolean := True)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Compose3Array
         (Pointer (This),
          xfs_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (xfs_0);
      
      end if;

      return RetVal;
   end Compose3Array;

    function LookAtFrom
     (This   : IDAStatics_Type;
      to_0   : Pointer_To_IDAPoint3;
      from_1 : Pointer_To_IDAPoint3;
      up_2   : Pointer_To_IDAVector3)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.LookAtFrom
         (Pointer (This),
          to_0,
          from_1,
          up_2,
          RetVal'Unchecked_Access));

      return RetVal;
   end LookAtFrom;

    function Get_IdentityTransform2
     (This  : IDAStatics_Type)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_IdentityTransform2
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_IdentityTransform2;

    function Translate2Anim
     (This  : IDAStatics_Type;
      tx_0  : Pointer_To_IDANumber;
      ty_1  : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate2Anim
         (Pointer (This),
          tx_0,
          ty_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate2Anim;

    function Translate2
     (This  : IDAStatics_Type;
      tx_0  : Interfaces.C.double;
      ty_1  : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate2
         (Pointer (This),
          tx_0,
          ty_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate2;

    function Translate2Rate
     (This  : IDAStatics_Type;
      tx_0  : Interfaces.C.double;
      ty_1  : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate2Rate
         (Pointer (This),
          tx_0,
          ty_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate2Rate;

    function Translate2Vector
     (This    : IDAStatics_Type;
      delta_0 : Pointer_To_IDAVector2)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate2Vector
         (Pointer (This),
          delta_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate2Vector;

    function Translate2Point
     (This  : IDAStatics_Type;
      pos_0 : Pointer_To_IDAPoint2)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate2Point
         (Pointer (This),
          pos_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Translate2Point;

    function Scale2Anim
     (This  : IDAStatics_Type;
      x_0   : Pointer_To_IDANumber;
      y_1   : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2Anim
         (Pointer (This),
          x_0,
          y_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2Anim;

    function Scale2
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2
         (Pointer (This),
          x_0,
          y_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2;

    function Scale2Rate
     (This  : IDAStatics_Type;
      x_0   : Interfaces.C.double;
      y_1   : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2Rate
         (Pointer (This),
          x_0,
          y_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2Rate;

    function Scale2Vector2
     (This             : IDAStatics_Type;
      obsoleteMethod_0 : Pointer_To_IDAVector2)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2Vector2
         (Pointer (This),
          obsoleteMethod_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2Vector2;

    function Scale2Vector
     (This        : IDAStatics_Type;
      scale_vec_0 : Pointer_To_IDAVector2)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2Vector
         (Pointer (This),
          scale_vec_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2Vector;

    function Scale2UniformAnim
     (This            : IDAStatics_Type;
      uniform_scale_0 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2UniformAnim
         (Pointer (This),
          uniform_scale_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2UniformAnim;

    function Scale2Uniform
     (This            : IDAStatics_Type;
      uniform_scale_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2Uniform
         (Pointer (This),
          uniform_scale_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2Uniform;

    function Scale2UniformRate
     (This            : IDAStatics_Type;
      uniform_scale_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale2UniformRate
         (Pointer (This),
          uniform_scale_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Scale2UniformRate;

    function Rotate2Anim
     (This    : IDAStatics_Type;
      angle_0 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate2Anim
         (Pointer (This),
          angle_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate2Anim;

    function Rotate2
     (This    : IDAStatics_Type;
      angle_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate2
         (Pointer (This),
          angle_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate2;

    function Rotate2Rate
     (This    : IDAStatics_Type;
      angle_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate2Rate
         (Pointer (This),
          angle_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate2Rate;

    function Rotate2Degrees
     (This    : IDAStatics_Type;
      angle_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate2Degrees
         (Pointer (This),
          angle_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate2Degrees;

    function Rotate2RateDegrees
     (This    : IDAStatics_Type;
      angle_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate2RateDegrees
         (Pointer (This),
          angle_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Rotate2RateDegrees;

    function XShear2Anim
     (This  : IDAStatics_Type;
      arg_0 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.XShear2Anim
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end XShear2Anim;

    function XShear2
     (This  : IDAStatics_Type;
      arg_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.XShear2
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end XShear2;

    function XShear2Rate
     (This  : IDAStatics_Type;
      arg_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.XShear2Rate
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end XShear2Rate;

    function YShear2Anim
     (This  : IDAStatics_Type;
      arg_0 : Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.YShear2Anim
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end YShear2Anim;

    function YShear2
     (This  : IDAStatics_Type;
      arg_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.YShear2
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end YShear2;

    function YShear2Rate
     (This  : IDAStatics_Type;
      arg_0 : Interfaces.C.double)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.YShear2Rate
         (Pointer (This),
          arg_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end YShear2Rate;

    function Transform3x2AnimEx
     (This    : IDAStatics_Type;
      m_0size : Interfaces.C.long;
      m_0     : Pointer_To_Pointer_To_IDANumber)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform3x2AnimEx
         (Pointer (This),
          m_0size,
          m_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Transform3x2AnimEx;

    function Transform3x2Anim
     (This  : IDAStatics_Type;
      m_0   : GNATCOM.Types.VARIANT;
      Free  : Boolean := True)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform3x2Anim
         (Pointer (This),
          m_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (m_0);
      
      end if;

      return RetVal;
   end Transform3x2Anim;

    function Compose2
     (This  : IDAStatics_Type;
      a_0   : Pointer_To_IDATransform2;
      b_1   : Pointer_To_IDATransform2)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Compose2
         (Pointer (This),
          a_0,
          b_1,
          RetVal'Unchecked_Access));

      return RetVal;
   end Compose2;

    function Compose2ArrayEx
     (This      : IDAStatics_Type;
      xfs_0size : Interfaces.C.long;
      xfs_0     : Pointer_To_Pointer_To_IDATransform2)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Compose2ArrayEx
         (Pointer (This),
          xfs_0size,
          xfs_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Compose2ArrayEx;

    function Compose2Array
     (This  : IDAStatics_Type;
      xfs_0 : GNATCOM.Types.VARIANT;
      Free  : Boolean := True)
     return Pointer_To_IDATransform2
   is
       RetVal : aliased Pointer_To_IDATransform2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Compose2Array
         (Pointer (This),
          xfs_0,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (xfs_0);
      
      end if;

      return RetVal;
   end Compose2Array;

    function Tuple
     (This      : IDAStatics_Type;
      obsolete1 : GNATCOM.Types.VARIANT;
      Free      : Boolean := True)
     return Pointer_To_IDATuple
   is
       RetVal : aliased Pointer_To_IDATuple;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Tuple
         (Pointer (This),
          obsolete1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (obsolete1);
      
      end if;

      return RetVal;
   end Tuple;

    function uArray
     (This      : IDAStatics_Type;
      obsolete1 : GNATCOM.Types.VARIANT;
      Free      : Boolean := True)
     return Pointer_To_IDAArray
   is
       RetVal : aliased Pointer_To_IDAArray;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uArray
         (Pointer (This),
          obsolete1,
          RetVal'Unchecked_Access));

      if Free then
               GNATCOM.Interface.Free (obsolete1);
      
      end if;

      return RetVal;
   end uArray;

    function Get_AreBlockingImportsComplete
     (This      : IDAStatics_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_AreBlockingImportsComplete
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_AreBlockingImportsComplete;

end StructuredGraphicControl.IDAStatics_Interface;

