with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAVector3_Interface is

   procedure Initialize (This : in out IDAVector3_Type) is
   begin
      Set_IID (This, IID_IDAVector3);
   end Initialize;

   function Pointer (This : IDAVector3_Type)
     return Pointer_To_IDAVector3
   is
   begin
      return To_Pointer_To_IDAVector3 (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAVector3_Type;
                     Pointer : in     Pointer_To_IDAVector3)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function GetClassName
     (This       : IDAVector3_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.GetClassName
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end GetClassName;

   procedure Init
     (This  : IDAVector3_Type;
      toBvr : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Init
         (Pointer (This),
          toBvr));

   end Init;

    function Importance
     (This               : IDAVector3_Type;
      relativeImportance : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Importance
         (Pointer (This),
          relativeImportance,
          RetVal'Unchecked_Access));

      return RetVal;
   end Importance;

    function RunOnce
     (This : IDAVector3_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RunOnce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RunOnce;

    function SubstituteTime
     (This  : IDAVector3_Type;
      xform : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SubstituteTime
         (Pointer (This),
          xform,
          RetVal'Unchecked_Access));

      return RetVal;
   end SubstituteTime;

   procedure SwitchTo
     (This     : IDAVector3_Type;
      SwitchTo : Pointer_To_IDABehavior)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchTo
         (Pointer (This),
          SwitchTo));

   end SwitchTo;

   procedure SwitchToNumber
     (This          : IDAVector3_Type;
      numToSwitchTo : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToNumber
         (Pointer (This),
          numToSwitchTo));

   end SwitchToNumber;

   procedure SwitchToString
     (This          : IDAVector3_Type;
      strToSwitchTo : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SwitchToString
         (Pointer (This),
          strToSwitchTo));

      if Free then
               GNATCOM.Interface.Free (strToSwitchTo);
      
      end if;

   end SwitchToString;

    function Hook
     (This     : IDAVector3_Type;
      notifier : Pointer_To_IDABvrHook)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Hook
         (Pointer (This),
          notifier,
          RetVal'Unchecked_Access));

      return RetVal;
   end Hook;

    function Duration
     (This     : IDAVector3_Type;
      Duration : Interfaces.C.double)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Duration
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end Duration;

    function DurationAnim
     (This     : IDAVector3_Type;
      Duration : Pointer_To_IDANumber)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DurationAnim
         (Pointer (This),
          Duration,
          RetVal'Unchecked_Access));

      return RetVal;
   end DurationAnim;

    function Repeat
     (This  : IDAVector3_Type;
      count : Interfaces.C.long)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Repeat
         (Pointer (This),
          count,
          RetVal'Unchecked_Access));

      return RetVal;
   end Repeat;

    function RepeatForever
     (This : IDAVector3_Type)
     return Pointer_To_IDABehavior
   is
       RetVal : aliased Pointer_To_IDABehavior;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RepeatForever
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end RepeatForever;

    function IsReady
     (This   : IDAVector3_Type;
      bBlock : GNATCOM.Types.VARIANT_BOOL)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.IsReady
         (Pointer (This),
          bBlock,
          RetVal'Unchecked_Access));

      return RetVal;
   end IsReady;

    function Get_Length
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Length
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Length;

    function Get_LengthSquared
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_LengthSquared
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_LengthSquared;

    function Normalize
     (This  : IDAVector3_Type)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Normalize
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Normalize;

    function MulAnim
     (This     : IDAVector3_Type;
      scalar_0 : Pointer_To_IDANumber)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.MulAnim
         (Pointer (This),
          scalar_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end MulAnim;

    function Mul
     (This     : IDAVector3_Type;
      scalar_0 : Interfaces.C.double)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Mul
         (Pointer (This),
          scalar_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Mul;

    function DivAnim
     (This     : IDAVector3_Type;
      scalar_0 : Pointer_To_IDANumber)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.DivAnim
         (Pointer (This),
          scalar_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end DivAnim;

    function Div
     (This     : IDAVector3_Type;
      scalar_0 : Interfaces.C.double)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Div
         (Pointer (This),
          scalar_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Div;

    function Get_X
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_X
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_X;

    function Get_Y
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Y
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Y;

    function Get_Z
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Z
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Z;

    function Get_SphericalCoordXYAngle
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SphericalCoordXYAngle
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SphericalCoordXYAngle;

    function Get_SphericalCoordYZAngle
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SphericalCoordYZAngle
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SphericalCoordYZAngle;

    function Get_SphericalCoordLength
     (This  : IDAVector3_Type)
     return Pointer_To_IDANumber
   is
       RetVal : aliased Pointer_To_IDANumber;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SphericalCoordLength
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SphericalCoordLength;

    function Transform
     (This  : IDAVector3_Type;
      xf_0  : Pointer_To_IDATransform3)
     return Pointer_To_IDAVector3
   is
       RetVal : aliased Pointer_To_IDAVector3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform
         (Pointer (This),
          xf_0,
          RetVal'Unchecked_Access));

      return RetVal;
   end Transform;

end StructuredGraphicControl.IDAVector3_Interface;

