with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IDAView_Interface is

   procedure Initialize (This : in out IDAView_Type) is
   begin
      Set_IID (This, IID_IDAView);
   end Initialize;

   function Pointer (This : IDAView_Type)
     return Pointer_To_IDAView
   is
   begin
      return To_Pointer_To_IDAView (Address (This));
   end Pointer;

   procedure Attach (This    : in out IDAView_Type;
                     Pointer : in     Pointer_To_IDAView)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_SimulationTime
     (This    : IDAView_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SimulationTime
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SimulationTime;

    function Tick
     (This         : IDAView_Type;
      simTime      : Interfaces.C.double)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Tick
         (Pointer (This),
          simTime,
          RetVal'Unchecked_Access));

      return RetVal;
   end Tick;

   procedure Render
     (This : IDAView_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Render
         (Pointer (This)));

   end Render;

    function AddBvrToRun
     (This : IDAView_Type;
      bvr  : Pointer_To_IDABehavior)
     return Interfaces.C.long
   is
       RetVal : aliased Interfaces.C.long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddBvrToRun
         (Pointer (This),
          bvr,
          RetVal'Unchecked_Access));

      return RetVal;
   end AddBvrToRun;

   procedure RemoveRunningBvr
     (This : IDAView_Type;
      id   : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RemoveRunningBvr
         (Pointer (This),
          id));

   end RemoveRunningBvr;

   procedure StartModel
     (This      : IDAView_Type;
      pImage    : Pointer_To_IDAImage;
      pSound    : Pointer_To_IDASound;
      startTime : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.StartModel
         (Pointer (This),
          pImage,
          pSound,
          startTime));

   end StartModel;

   procedure StopModel
     (This : IDAView_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.StopModel
         (Pointer (This)));

   end StopModel;

    function Get_Window
     (This : IDAView_Type)
     return Interfaces.C.long
   is
       RetVal : aliased Interfaces.C.long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Window
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Window;

   procedure Put_Window
     (This : IDAView_Type;
      hwnd : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Window
         (Pointer (This),
          hwnd));

   end Put_Window;

    function Get_IDirectDrawSurface
     (This   : IDAView_Type)
     return GNATCOM.Types.Pointer_To_IUnknown
   is
       RetVal : aliased GNATCOM.Types.Pointer_To_IUnknown;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_IDirectDrawSurface
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_IDirectDrawSurface;

   procedure Put_IDirectDrawSurface
     (This   : IDAView_Type;
      ddsurf : GNATCOM.Types.Pointer_To_IUnknown)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_IDirectDrawSurface
         (Pointer (This),
          ddsurf));

   end Put_IDirectDrawSurface;

    function Get_DC
     (This : IDAView_Type)
     return wireHDC
   is
       RetVal : aliased wireHDC;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DC
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DC;

   procedure Put_DC
     (This : IDAView_Type;
      DC   : wireHDC)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_DC
         (Pointer (This),
          DC));

   end Put_DC;

    function Get_CompositeDirectlyToTarget
     (This            : IDAView_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_CompositeDirectlyToTarget
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_CompositeDirectlyToTarget;

   procedure Put_CompositeDirectlyToTarget
     (This            : IDAView_Type;
      composeToTarget : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_CompositeDirectlyToTarget
         (Pointer (This),
          composeToTarget));

   end Put_CompositeDirectlyToTarget;

   procedure SetViewport
     (This : IDAView_Type;
      xPos : Interfaces.C.long;
      yPos : Interfaces.C.long;
      w    : Interfaces.C.long;
      h    : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SetViewport
         (Pointer (This),
          xPos,
          yPos,
          w,
          h));

   end SetViewport;

   procedure SetClipRect
     (This : IDAView_Type;
      xPos : Interfaces.C.long;
      yPos : Interfaces.C.long;
      w    : Interfaces.C.long;
      h    : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SetClipRect
         (Pointer (This),
          xPos,
          yPos,
          w,
          h));

   end SetClipRect;

   procedure RePaint
     (This : IDAView_Type;
      xPos : Interfaces.C.long;
      yPos : Interfaces.C.long;
      w    : Interfaces.C.long;
      h    : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.RePaint
         (Pointer (This),
          xPos,
          yPos,
          w,
          h));

   end RePaint;

   procedure PaletteChanged
     (This : IDAView_Type;
      bNew : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.PaletteChanged
         (Pointer (This),
          bNew));

   end PaletteChanged;

    function Get_Site
     (This      : IDAView_Type)
     return Pointer_To_IDAViewSite
   is
       RetVal : aliased Pointer_To_IDAViewSite;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Site
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Site;

   procedure Put_Site
     (This      : IDAView_Type;
      pViewSite : Pointer_To_IDAViewSite)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Site
         (Pointer (This),
          pViewSite));

   end Put_Site;

   procedure Put_ClientSite
     (This        : IDAView_Type;
      pClientSite : Pointer_To_IOleClientSite)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ClientSite
         (Pointer (This),
          pClientSite));

   end Put_ClientSite;

    function Get_ClientSite
     (This        : IDAView_Type)
     return Pointer_To_IOleClientSite
   is
       RetVal : aliased Pointer_To_IOleClientSite;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ClientSite
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ClientSite;

   procedure OnMouseMove
     (This      : IDAView_Type;
      uwhen     : Interfaces.C.double;
      xPos      : Interfaces.C.long;
      yPos      : Interfaces.C.long;
      modifiers : Interfaces.C.unsigned_char)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OnMouseMove
         (Pointer (This),
          uwhen,
          xPos,
          yPos,
          modifiers));

   end OnMouseMove;

   procedure OnMouseButton
     (This      : IDAView_Type;
      uwhen     : Interfaces.C.double;
      xPos      : Interfaces.C.long;
      yPos      : Interfaces.C.long;
      button    : Interfaces.C.unsigned_char;
      bPressed  : GNATCOM.Types.VARIANT_BOOL;
      modifiers : Interfaces.C.unsigned_char)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OnMouseButton
         (Pointer (This),
          uwhen,
          xPos,
          yPos,
          button,
          bPressed,
          modifiers));

   end OnMouseButton;

   procedure OnKey
     (This      : IDAView_Type;
      uwhen     : Interfaces.C.double;
      key       : Interfaces.C.long;
      bPressed  : GNATCOM.Types.VARIANT_BOOL;
      modifiers : Interfaces.C.unsigned_char)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OnKey
         (Pointer (This),
          uwhen,
          key,
          bPressed,
          modifiers));

   end OnKey;

   procedure OnFocus
     (This      : IDAView_Type;
      bHasFocus : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.OnFocus
         (Pointer (This),
          bHasFocus));

   end OnFocus;

    function Get_Preferences
     (This  : IDAView_Type)
     return Pointer_To_IDAPreferences
   is
       RetVal : aliased Pointer_To_IDAPreferences;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Preferences
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Preferences;

    function QueryHitPoint
     (This       : IDAView_Type;
      dwAspect   : Interfaces.C.unsigned_long;
      prcBounds  : Pointer_To_tagRECT;
      ptLoc      : tagPOINT;
      lCloseHint : Interfaces.C.long)
     return Interfaces.C.unsigned_long
   is
       RetVal : aliased Interfaces.C.unsigned_long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.QueryHitPoint
         (Pointer (This),
          dwAspect,
          prcBounds,
          ptLoc,
          lCloseHint,
          RetVal'Unchecked_Access));

      return RetVal;
   end QueryHitPoint;

end StructuredGraphicControl.IDAView_Interface;

