with GNATCOM.Dispinterface;

package StructuredGraphicControl.IDAView_Interface is

   type IDAView_Type is
     new GNATCOM.Dispinterface.Dispinterface_Type with null record;

   procedure Initialize (This : in out IDAView_Type);

   function Pointer (This : IDAView_Type)
     return Pointer_To_IDAView;

   procedure Attach (This    : in out IDAView_Type;
                     Pointer : in     Pointer_To_IDAView);

   function Get_SimulationTime
     (This    : IDAView_Type)
     return Interfaces.C.double;
   --  The current simulation time.

   function Tick
     (This         : IDAView_Type;
      simTime      : Interfaces.C.double)
     return GNATCOM.Types.VARIANT_BOOL;

   procedure Render
     (This : IDAView_Type);

   function AddBvrToRun
     (This : IDAView_Type;
      bvr  : Pointer_To_IDABehavior)
     return Interfaces.C.long;

   procedure RemoveRunningBvr
     (This : IDAView_Type;
      id   : Interfaces.C.long);

   procedure StartModel
     (This      : IDAView_Type;
      pImage    : Pointer_To_IDAImage;
      pSound    : Pointer_To_IDASound;
      startTime : Interfaces.C.double);

   procedure StopModel
     (This : IDAView_Type);

   function Get_Window
     (This : IDAView_Type)
     return Interfaces.C.long;
   --  The window to display the view in.

   procedure Put_Window
     (This : IDAView_Type;
      hwnd : Interfaces.C.long);
   --  The window to display the view in.

   function Get_IDirectDrawSurface
     (This   : IDAView_Type)
     return GNATCOM.Types.Pointer_To_IUnknown;
   --  The DirectDraw Surface to display the view in.

   procedure Put_IDirectDrawSurface
     (This   : IDAView_Type;
      ddsurf : GNATCOM.Types.Pointer_To_IUnknown);
   --  The DirectDraw Surface to display the view in.

   function Get_DC
     (This : IDAView_Type)
     return wireHDC;
   --  The HDC to display the view in.

   procedure Put_DC
     (This : IDAView_Type;
      DC   : wireHDC);
   --  The HDC to display the view in.

   function Get_CompositeDirectlyToTarget
     (This            : IDAView_Type)
     return GNATCOM.Types.VARIANT_BOOL;
   --  Composition mode: compose to backbuffer or directly to target

   procedure Put_CompositeDirectlyToTarget
     (This            : IDAView_Type;
      composeToTarget : GNATCOM.Types.VARIANT_BOOL);
   --  Composition mode: compose to backbuffer or directly to target

   procedure SetViewport
     (This : IDAView_Type;
      xPos : Interfaces.C.long;
      yPos : Interfaces.C.long;
      w    : Interfaces.C.long;
      h    : Interfaces.C.long);

   procedure SetClipRect
     (This : IDAView_Type;
      xPos : Interfaces.C.long;
      yPos : Interfaces.C.long;
      w    : Interfaces.C.long;
      h    : Interfaces.C.long);

   procedure RePaint
     (This : IDAView_Type;
      xPos : Interfaces.C.long;
      yPos : Interfaces.C.long;
      w    : Interfaces.C.long;
      h    : Interfaces.C.long);

   procedure PaletteChanged
     (This : IDAView_Type;
      bNew : GNATCOM.Types.VARIANT_BOOL);

   function Get_Site
     (This      : IDAView_Type)
     return Pointer_To_IDAViewSite;

   procedure Put_Site
     (This      : IDAView_Type;
      pViewSite : Pointer_To_IDAViewSite);

   procedure Put_ClientSite
     (This        : IDAView_Type;
      pClientSite : Pointer_To_IOleClientSite);

   function Get_ClientSite
     (This        : IDAView_Type)
     return Pointer_To_IOleClientSite;

   procedure OnMouseMove
     (This      : IDAView_Type;
      uwhen     : Interfaces.C.double;
      xPos      : Interfaces.C.long;
      yPos      : Interfaces.C.long;
      modifiers : Interfaces.C.unsigned_char);

   procedure OnMouseButton
     (This      : IDAView_Type;
      uwhen     : Interfaces.C.double;
      xPos      : Interfaces.C.long;
      yPos      : Interfaces.C.long;
      button    : Interfaces.C.unsigned_char;
      bPressed  : GNATCOM.Types.VARIANT_BOOL;
      modifiers : Interfaces.C.unsigned_char);

   procedure OnKey
     (This      : IDAView_Type;
      uwhen     : Interfaces.C.double;
      key       : Interfaces.C.long;
      bPressed  : GNATCOM.Types.VARIANT_BOOL;
      modifiers : Interfaces.C.unsigned_char);

   procedure OnFocus
     (This      : IDAView_Type;
      bHasFocus : GNATCOM.Types.VARIANT_BOOL);

   function Get_Preferences
     (This  : IDAView_Type)
     return Pointer_To_IDAPreferences;

   function QueryHitPoint
     (This       : IDAView_Type;
      dwAspect   : Interfaces.C.unsigned_long;
      prcBounds  : Pointer_To_tagRECT;
      ptLoc      : tagPOINT;
      lCloseHint : Interfaces.C.long)
     return Interfaces.C.unsigned_long;

end StructuredGraphicControl.IDAView_Interface;

