with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IMMSeq_Interface is

   procedure Initialize (This : in out IMMSeq_Type) is
   begin
      Set_IID (This, IID_IMMSeq);
   end Initialize;

   function Pointer (This : IMMSeq_Type)
     return Pointer_To_IMMSeq
   is
   begin
      return To_Pointer_To_IMMSeq (Address (This));
   end Pointer;

   procedure Attach (This    : in out IMMSeq_Type;
                     Pointer : in     Pointer_To_IMMSeq)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_Time
     (This            : IMMSeq_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Time
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Time;

    function Get_PlayState
     (This        : IMMSeq_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PlayState
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PlayState;

   procedure Putu_Cookie
     (This     : IMMSeq_Type;
      plCookie : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Putu_Cookie
         (Pointer (This),
          plCookie));

   end Putu_Cookie;

    function Getu_Cookie
     (This     : IMMSeq_Type)
     return Interfaces.C.long
   is
       RetVal : aliased Interfaces.C.long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Getu_Cookie
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Getu_Cookie;

   procedure Play
     (This : IMMSeq_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Play
         (Pointer (This)));

   end Play;

   procedure Pause
     (This : IMMSeq_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Pause
         (Pointer (This)));

   end Pause;

   procedure Stop
     (This : IMMSeq_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Stop
         (Pointer (This)));

   end Stop;

   procedure uAt
     (This              : IMMSeq_Type;
      varStartTime      : GNATCOM.Types.VARIANT;
      bstrScriptlet     : GNATCOM.Types.BSTR;
      varRepeatCount    : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      varSampleRate     : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      varTiebreakNumber : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      varDropTolerance  : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free              : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.uAt
         (Pointer (This),
          varStartTime,
          bstrScriptlet,
          varRepeatCount,
          varSampleRate,
          varTiebreakNumber,
          varDropTolerance));

      if Free then
               GNATCOM.Interface.Free (varStartTime);
               GNATCOM.Interface.Free (bstrScriptlet);
               GNATCOM.Interface.Free (varRepeatCount);
               GNATCOM.Interface.Free (varSampleRate);
               GNATCOM.Interface.Free (varTiebreakNumber);
               GNATCOM.Interface.Free (varDropTolerance);
      
      end if;

   end uAt;

   procedure Clear
     (This : IMMSeq_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Clear
         (Pointer (This)));

   end Clear;

   procedure Seek
     (This        : IMMSeq_Type;
      dblSeekTime : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Seek
         (Pointer (This),
          dblSeekTime));

   end Seek;

end StructuredGraphicControl.IMMSeq_Interface;

