with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.IPathCtl_Interface is

   procedure Initialize (This : in out IPathCtl_Type) is
   begin
      Set_IID (This, IID_IPathCtl);
   end Initialize;

   function Pointer (This : IPathCtl_Type)
     return Pointer_To_IPathCtl
   is
   begin
      return To_Pointer_To_IPathCtl (Address (This));
   end Pointer;

   procedure Attach (This    : in out IPathCtl_Type;
                     Pointer : in     Pointer_To_IPathCtl)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_Target
     (This       : IPathCtl_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Target
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Target;

   procedure Put_Target
     (This       : IPathCtl_Type;
      bstrTarget : GNATCOM.Types.BSTR;
      Free       : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Target
         (Pointer (This),
          bstrTarget));

      if Free then
               GNATCOM.Interface.Free (bstrTarget);
      
      end if;

   end Put_Target;

    function Get_Duration
     (This        : IPathCtl_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Duration
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Duration;

   procedure Put_Duration
     (This        : IPathCtl_Type;
      dblDuration : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Duration
         (Pointer (This),
          dblDuration));

   end Put_Duration;

    function Get_Library
     (This      : IPathCtl_Type)
     return Pointer_To_IDAStatics
   is
       RetVal : aliased Pointer_To_IDAStatics;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Library
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Library;

    function Get_Repeat
     (This    : IPathCtl_Type)
     return Interfaces.C.long
   is
       RetVal : aliased Interfaces.C.long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Repeat
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Repeat;

   procedure Put_Repeat
     (This    : IPathCtl_Type;
      iRepeat : Interfaces.C.long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Repeat
         (Pointer (This),
          iRepeat));

   end Put_Repeat;

    function Get_Bounce
     (This    : IPathCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Bounce
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Bounce;

   procedure Put_Bounce
     (This    : IPathCtl_Type;
      fBounce : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Bounce
         (Pointer (This),
          fBounce));

   end Put_Bounce;

    function Get_AutoStart
     (This       : IPathCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_AutoStart
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_AutoStart;

   procedure Put_AutoStart
     (This       : IPathCtl_Type;
      fAutoStart : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_AutoStart
         (Pointer (This),
          fAutoStart));

   end Put_AutoStart;

    function Get_PlayState
     (This  : IPathCtl_Type)
     return PlayStateConstant
   is
       RetVal : aliased PlayStateConstant;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PlayState
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PlayState;

    function Get_Time
     (This     : IPathCtl_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Time
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Time;

    function Get_Direction
     (This : IPathCtl_Type)
     return DirectionConstant
   is
       RetVal : aliased DirectionConstant;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Direction
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Direction;

   procedure Put_Direction
     (This : IPathCtl_Type;
      Dir  : DirectionConstant)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Direction
         (Pointer (This),
          Dir));

   end Put_Direction;

    function Get_Relative
     (This      : IPathCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Relative
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Relative;

   procedure Put_Relative
     (This      : IPathCtl_Type;
      bRelative : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Relative
         (Pointer (This),
          bRelative));

   end Put_Relative;

    function Get_TimerInterval
     (This     : IPathCtl_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_TimerInterval
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_TimerInterval;

   procedure Put_TimerInterval
     (This     : IPathCtl_Type;
      Interval : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_TimerInterval
         (Pointer (This),
          Interval));

   end Put_TimerInterval;

    function Get_Path
     (This   : IPathCtl_Type)
     return Pointer_To_IDAPath2
   is
       RetVal : aliased Pointer_To_IDAPath2;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Path
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Path;

   procedure Put_Path
     (This   : IPathCtl_Type;
      ppPath : Pointer_To_IDAPath2)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Path
         (Pointer (This),
          ppPath));

   end Put_Path;

   procedure Stop
     (This : IPathCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Stop
         (Pointer (This)));

   end Stop;

   procedure Pause
     (This : IPathCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Pause
         (Pointer (This)));

   end Pause;

   procedure Play
     (This : IPathCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Play
         (Pointer (This)));

   end Play;

   procedure Seek
     (This    : IPathCtl_Type;
      dblTime : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Seek
         (Pointer (This),
          dblTime));

   end Seek;

   procedure Oval
     (This   : IPathCtl_Type;
      StartX : Interfaces.C.double;
      StartY : Interfaces.C.double;
      Width  : Interfaces.C.double;
      Height : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Oval
         (Pointer (This),
          StartX,
          StartY,
          Width,
          Height));

   end Oval;

   procedure Rect
     (This   : IPathCtl_Type;
      StartX : Interfaces.C.double;
      StartY : Interfaces.C.double;
      Width  : Interfaces.C.double;
      Height : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rect
         (Pointer (This),
          StartX,
          StartY,
          Width,
          Height));

   end Rect;

   procedure Polyline
     (This    : IPathCtl_Type;
      nPoints : Interfaces.C.long;
      Points  : GNATCOM.Types.VARIANT;
      Free    : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Polyline
         (Pointer (This),
          nPoints,
          Points));

      if Free then
               GNATCOM.Interface.Free (Points);
      
      end if;

   end Polyline;

   procedure Polygon
     (This    : IPathCtl_Type;
      nPoints : Interfaces.C.long;
      Points  : GNATCOM.Types.VARIANT;
      Free    : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Polygon
         (Pointer (This),
          nPoints,
          Points));

      if Free then
               GNATCOM.Interface.Free (Points);
      
      end if;

   end Polygon;

   procedure AddTimeMarker
     (This           : IPathCtl_Type;
      dblTime        : Interfaces.C.double;
      bstrMarkerName : GNATCOM.Types.BSTR;
      bAbsolute      : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free           : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddTimeMarker
         (Pointer (This),
          dblTime,
          bstrMarkerName,
          bAbsolute));

      if Free then
               GNATCOM.Interface.Free (bstrMarkerName);
               GNATCOM.Interface.Free (bAbsolute);
      
      end if;

   end AddTimeMarker;

   procedure KeyFrame
     (This          : IPathCtl_Type;
      iNumPoints    : Interfaces.C.unsigned;
      varPoints     : GNATCOM.Types.VARIANT;
      varTimePoints : GNATCOM.Types.VARIANT;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.KeyFrame
         (Pointer (This),
          iNumPoints,
          varPoints,
          varTimePoints));

      if Free then
               GNATCOM.Interface.Free (varPoints);
               GNATCOM.Interface.Free (varTimePoints);
      
      end if;

   end KeyFrame;

   procedure Spline
     (This       : IPathCtl_Type;
      iNumPoints : Interfaces.C.unsigned;
      varPoints  : GNATCOM.Types.VARIANT;
      Free       : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Spline
         (Pointer (This),
          iNumPoints,
          varPoints));

      if Free then
               GNATCOM.Interface.Free (varPoints);
      
      end if;

   end Spline;

end StructuredGraphicControl.IPathCtl_Interface;

