with GNATCOM.Dispinterface;

package StructuredGraphicControl.IPathCtl_Object is

   type IPathCtl_Type is
     new GNATCOM.Dispinterface.Dispinterface_Type with null record;

   function Get_Target
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Sets or returns the name of the object to move

   procedure Put_Target
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Sets or returns the name of the object to move

   function Get_Duration
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Specifies the duration of the path playback

   procedure Put_Duration
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Specifies the duration of the path playback

   function Get_Library
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Gets the Direct Animation Library

   function Get_Repeat
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Sets or returns the number of times to loop playback.  Specify -1 to
   --  loop infinitely

   procedure Put_Repeat
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Sets or returns the number of times to loop playback.  Specify -1 to
   --  loop infinitely

   function Get_Bounce
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Sets the path to either stop at the end of the path or reverse direction
   --  and continue playback

   procedure Put_Bounce
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Sets the path to either stop at the end of the path or reverse direction
   --  and continue playback

   function Get_AutoStart
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;

   procedure Put_AutoStart
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);

   function Get_PlayState
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Returns the current playback state of the path

   function Get_Time
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Returns the elapsed playback time of the path

   function Get_Direction
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Sets or returns the direction of the path playback, either forward or
   --  reverse

   procedure Put_Direction
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Sets or returns the direction of the path playback, either forward or
   --  reverse

   function Get_Relative
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Sets or returns path coordinate positioning; absolute position or
   --  relative to the target

   procedure Put_Relative
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Sets or returns path coordinate positioning; absolute position or
   --  relative to the target

   function Get_TimerInterval
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Sets or returns the interval between path updates

   procedure Put_TimerInterval
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Sets or returns the interval between path updates

   function Get_Path
     (This : IPathCtl_Type)
     return GNATCOM.Types.VARIANT;
   --  Sets or returns the current path as a DirectAnimation behavior

   procedure Put_Path
     (This : IPathCtl_Type;
      P1   : GNATCOM.Types.VARIANT;
      Free : Boolean := True);
   --  Sets or returns the current path as a DirectAnimation behavior

   procedure Stop
     (This : IPathCtl_Type);
   --  Stops playback and resets the path to the beginning

   procedure Pause
     (This : IPathCtl_Type);
   --  Stops playback of the path and maintains current position

   procedure Play
     (This : IPathCtl_Type);
   --  Starts playback of the path

   procedure Seek
     (This    : IPathCtl_Type;
      dblTime : GNATCOM.Types.VARIANT;
      Free    : Boolean := True);
   --  Jumps to a new position along the path

   procedure Oval
     (This   : IPathCtl_Type;
      StartX : GNATCOM.Types.VARIANT;
      StartY : GNATCOM.Types.VARIANT;
      Width  : GNATCOM.Types.VARIANT;
      Height : GNATCOM.Types.VARIANT;
      Free   : Boolean := True);
   --  Defines an oval-shaped path

   procedure Rect
     (This   : IPathCtl_Type;
      StartX : GNATCOM.Types.VARIANT;
      StartY : GNATCOM.Types.VARIANT;
      Width  : GNATCOM.Types.VARIANT;
      Height : GNATCOM.Types.VARIANT;
      Free   : Boolean := True);
   --  Defines a rectangle-shaped path

   procedure Polyline
     (This    : IPathCtl_Type;
      nPoints : GNATCOM.Types.VARIANT;
      Points  : GNATCOM.Types.VARIANT;
      Free    : Boolean := True);
   --  Defines an open multipoint path

   procedure Polygon
     (This    : IPathCtl_Type;
      nPoints : GNATCOM.Types.VARIANT;
      Points  : GNATCOM.Types.VARIANT;
      Free    : Boolean := True);
   --  Defines a closed multipoint path

   procedure AddTimeMarker
     (This           : IPathCtl_Type;
      dblTime        : GNATCOM.Types.VARIANT;
      bstrMarkerName : GNATCOM.Types.VARIANT;
      bAbsolute      : GNATCOM.Types.VARIANT
        := GNATCOM.Types.VARIANT_MISSING;
      Free           : Boolean := True);
   --  Creates a marker that fires an event at a specific time

   procedure KeyFrame
     (This          : IPathCtl_Type;
      iNumPoints    : GNATCOM.Types.VARIANT;
      varPoints     : GNATCOM.Types.VARIANT;
      varTimePoints : GNATCOM.Types.VARIANT;
      Free          : Boolean := True);
   --  Defines X and Y coordinates along a path and the time to reach each
   --  point

   procedure Spline
     (This       : IPathCtl_Type;
      iNumPoints : GNATCOM.Types.VARIANT;
      varPoints  : GNATCOM.Types.VARIANT;
      Free       : Boolean := True);
   --  Defines a cubic, uniform knot vector spline path

end StructuredGraphicControl.IPathCtl_Object;

