with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.ISGrfxCtl_Interface is

   procedure Initialize (This : in out ISGrfxCtl_Type) is
   begin
      Set_IID (This, IID_ISGrfxCtl);
   end Initialize;

   function Pointer (This : ISGrfxCtl_Type)
     return Pointer_To_ISGrfxCtl
   is
   begin
      return To_Pointer_To_ISGrfxCtl (Address (This));
   end Pointer;

   procedure Attach (This    : in out ISGrfxCtl_Type;
                     Pointer : in     Pointer_To_ISGrfxCtl)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_SourceURL
     (This          : ISGrfxCtl_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SourceURL
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SourceURL;

   procedure Put_SourceURL
     (This          : ISGrfxCtl_Type;
      bstrSourceURL : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_SourceURL
         (Pointer (This),
          bstrSourceURL));

      if Free then
               GNATCOM.Interface.Free (bstrSourceURL);
      
      end if;

   end Put_SourceURL;

    function Get_CoordinateSystem
     (This        : ISGrfxCtl_Type)
     return CoordSystemConstant
   is
       RetVal : aliased CoordSystemConstant;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_CoordinateSystem
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_CoordinateSystem;

   procedure Put_CoordinateSystem
     (This        : ISGrfxCtl_Type;
      CoordSystem : CoordSystemConstant)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_CoordinateSystem
         (Pointer (This),
          CoordSystem));

   end Put_CoordinateSystem;

    function Get_MouseEventsEnabled
     (This     : ISGrfxCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_MouseEventsEnabled
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_MouseEventsEnabled;

   procedure Put_MouseEventsEnabled
     (This     : ISGrfxCtl_Type;
      fEnabled : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_MouseEventsEnabled
         (Pointer (This),
          fEnabled));

   end Put_MouseEventsEnabled;

    function Get_ExtentTop
     (This       : ISGrfxCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ExtentTop
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ExtentTop;

   procedure Put_ExtentTop
     (This       : ISGrfxCtl_Type;
      iExtentTop : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ExtentTop
         (Pointer (This),
          iExtentTop));

   end Put_ExtentTop;

    function Get_ExtentLeft
     (This        : ISGrfxCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ExtentLeft
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ExtentLeft;

   procedure Put_ExtentLeft
     (This        : ISGrfxCtl_Type;
      iExtentLeft : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ExtentLeft
         (Pointer (This),
          iExtentLeft));

   end Put_ExtentLeft;

    function Get_ExtentWidth
     (This         : ISGrfxCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ExtentWidth
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ExtentWidth;

   procedure Put_ExtentWidth
     (This         : ISGrfxCtl_Type;
      iExtentWidth : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ExtentWidth
         (Pointer (This),
          iExtentWidth));

   end Put_ExtentWidth;

    function Get_ExtentHeight
     (This          : ISGrfxCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ExtentHeight
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ExtentHeight;

   procedure Put_ExtentHeight
     (This          : ISGrfxCtl_Type;
      iExtentHeight : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ExtentHeight
         (Pointer (This),
          iExtentHeight));

   end Put_ExtentHeight;

    function Get_HighQuality
     (This          : ISGrfxCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_HighQuality
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_HighQuality;

   procedure Put_HighQuality
     (This          : ISGrfxCtl_Type;
      pfHighQuality : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_HighQuality
         (Pointer (This),
          pfHighQuality));

   end Put_HighQuality;

    function Get_Library
     (This      : ISGrfxCtl_Type)
     return Pointer_To_IDAStatics
   is
       RetVal : aliased Pointer_To_IDAStatics;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Library
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Library;

    function Get_Image
     (This    : ISGrfxCtl_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Image
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Image;

   procedure Put_Image
     (This    : ISGrfxCtl_Type;
      ppImage : Pointer_To_IDAImage)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Image
         (Pointer (This),
          ppImage));

   end Put_Image;

    function Get_Transform
     (This        : ISGrfxCtl_Type)
     return Pointer_To_IDATransform3
   is
       RetVal : aliased Pointer_To_IDATransform3;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Transform
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Transform;

   procedure Put_Transform
     (This        : ISGrfxCtl_Type;
      ppTransform : Pointer_To_IDATransform3)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Transform
         (Pointer (This),
          ppTransform));

   end Put_Transform;

    function Get_DrawingSurface
     (This             : ISGrfxCtl_Type)
     return Pointer_To_IDADrawingSurface
   is
       RetVal : aliased Pointer_To_IDADrawingSurface;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DrawingSurface
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DrawingSurface;

   procedure Put_DrawingSurface
     (This             : ISGrfxCtl_Type;
      ppDrawingSurface : Pointer_To_IDADrawingSurface)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_DrawingSurface
         (Pointer (This),
          ppDrawingSurface));

   end Put_DrawingSurface;

    function Get_DrawSurface
     (This             : ISGrfxCtl_Type)
     return Pointer_To_IDADrawingSurface
   is
       RetVal : aliased Pointer_To_IDADrawingSurface;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_DrawSurface
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_DrawSurface;

   procedure Put_DrawSurface
     (This             : ISGrfxCtl_Type;
      ppDrawingSurface : Pointer_To_IDADrawingSurface)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_DrawSurface
         (Pointer (This),
          ppDrawingSurface));

   end Put_DrawSurface;

    function Get_PreserveAspectRatio
     (This      : ISGrfxCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PreserveAspectRatio
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PreserveAspectRatio;

   procedure Put_PreserveAspectRatio
     (This      : ISGrfxCtl_Type;
      fPreserve : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_PreserveAspectRatio
         (Pointer (This),
          fPreserve));

   end Put_PreserveAspectRatio;

   procedure Clear
     (This : ISGrfxCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Clear
         (Pointer (This)));

   end Clear;

   procedure Rotate
     (This        : ISGrfxCtl_Type;
      dblXRot     : Interfaces.C.double;
      dblYRot     : Interfaces.C.double;
      dblZRot     : Interfaces.C.double;
      varReserved : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free        : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Rotate
         (Pointer (This),
          dblXRot,
          dblYRot,
          dblZRot,
          varReserved));

      if Free then
               GNATCOM.Interface.Free (varReserved);
      
      end if;

   end Rotate;

   procedure Scale
     (This        : ISGrfxCtl_Type;
      dblXScale   : Interfaces.C.double;
      dblYScale   : Interfaces.C.double;
      dblZScale   : Interfaces.C.double;
      varReserved : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free        : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Scale
         (Pointer (This),
          dblXScale,
          dblYScale,
          dblZScale,
          varReserved));

      if Free then
               GNATCOM.Interface.Free (varReserved);
      
      end if;

   end Scale;

   procedure SetIdentity
     (This : ISGrfxCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.SetIdentity
         (Pointer (This)));

   end SetIdentity;

   procedure Transform4x4
     (This   : ISGrfxCtl_Type;
      matrix : GNATCOM.Types.VARIANT;
      Free   : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Transform4x4
         (Pointer (This),
          matrix));

      if Free then
               GNATCOM.Interface.Free (matrix);
      
      end if;

   end Transform4x4;

   procedure Translate
     (This        : ISGrfxCtl_Type;
      dblXOrigin  : Interfaces.C.double;
      dblYOrigin  : Interfaces.C.double;
      dblZOrigin  : Interfaces.C.double;
      varReserved : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free        : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Translate
         (Pointer (This),
          dblXOrigin,
          dblYOrigin,
          dblZOrigin,
          varReserved));

      if Free then
               GNATCOM.Interface.Free (varReserved);
      
      end if;

   end Translate;

end StructuredGraphicControl.ISGrfxCtl_Interface;

