with GNATCOM.Dispinterface;

package StructuredGraphicControl.ISGrfxCtl_Interface is

   type ISGrfxCtl_Type is
     new GNATCOM.Dispinterface.Dispinterface_Type with null record;

   procedure Initialize (This : in out ISGrfxCtl_Type);

   function Pointer (This : ISGrfxCtl_Type)
     return Pointer_To_ISGrfxCtl;

   procedure Attach (This    : in out ISGrfxCtl_Type;
                     Pointer : in     Pointer_To_ISGrfxCtl);

   function Get_SourceURL
     (This          : ISGrfxCtl_Type)
     return GNATCOM.Types.BSTR;
   --  Sets or returns the URL of a file containing Structured Graphics drawing
   --  primitives

   procedure Put_SourceURL
     (This          : ISGrfxCtl_Type;
      bstrSourceURL : GNATCOM.Types.BSTR;
      Free          : Boolean := True);
   --  Sets or returns the URL of a file containing Structured Graphics drawing
   --  primitives

   function Get_CoordinateSystem
     (This        : ISGrfxCtl_Type)
     return CoordSystemConstant;
   --  Sets or returns the coordinate system to use for the world

   procedure Put_CoordinateSystem
     (This        : ISGrfxCtl_Type;
      CoordSystem : CoordSystemConstant);
   --  Sets or returns the coordinate system to use for the world

   function Get_MouseEventsEnabled
     (This     : ISGrfxCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL;
   --  Enables or disables mouse events

   procedure Put_MouseEventsEnabled
     (This     : ISGrfxCtl_Type;
      fEnabled : GNATCOM.Types.VARIANT_BOOL);
   --  Enables or disables mouse events

   function Get_ExtentTop
     (This       : ISGrfxCtl_Type)
     return Interfaces.C.int;
   --  Sets or returns the vertical coordinates for the top edge of the logical
   --  coordinate system

   procedure Put_ExtentTop
     (This       : ISGrfxCtl_Type;
      iExtentTop : Interfaces.C.int);
   --  Sets or returns the vertical coordinates for the top edge of the logical
   --  coordinate system

   function Get_ExtentLeft
     (This        : ISGrfxCtl_Type)
     return Interfaces.C.int;
   --  Sets or returns the horizontal coordinates for the left edge of the
   --  logical coordinate system

   procedure Put_ExtentLeft
     (This        : ISGrfxCtl_Type;
      iExtentLeft : Interfaces.C.int);
   --  Sets or returns the horizontal coordinates for the left edge of the
   --  logical coordinate system

   function Get_ExtentWidth
     (This         : ISGrfxCtl_Type)
     return Interfaces.C.int;
   --  Sets or returns the width of the logical coordinate system

   procedure Put_ExtentWidth
     (This         : ISGrfxCtl_Type;
      iExtentWidth : Interfaces.C.int);
   --  Sets or returns the width of the logical coordinate system

   function Get_ExtentHeight
     (This          : ISGrfxCtl_Type)
     return Interfaces.C.int;
   --  Sets or returns the height of the logical coordinate system

   procedure Put_ExtentHeight
     (This          : ISGrfxCtl_Type;
      iExtentHeight : Interfaces.C.int);
   --  Sets or returns the height of the logical coordinate system

   function Get_HighQuality
     (This          : ISGrfxCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL;
   --  Enables or disables anti-aliasing

   procedure Put_HighQuality
     (This          : ISGrfxCtl_Type;
      pfHighQuality : GNATCOM.Types.VARIANT_BOOL);
   --  Enables or disables anti-aliasing

   function Get_Library
     (This      : ISGrfxCtl_Type)
     return Pointer_To_IDAStatics;
   --  Gets the Direct Animation Library

   function Get_Image
     (This    : ISGrfxCtl_Type)
     return Pointer_To_IDAImage;
   --  Sets or returns the current DirectAnimation Image

   procedure Put_Image
     (This    : ISGrfxCtl_Type;
      ppImage : Pointer_To_IDAImage);
   --  Sets or returns the current DirectAnimation Image

   function Get_Transform
     (This        : ISGrfxCtl_Type)
     return Pointer_To_IDATransform3;
   --  Sets or returns the current DirectAnimation transform

   procedure Put_Transform
     (This        : ISGrfxCtl_Type;
      ppTransform : Pointer_To_IDATransform3);
   --  Sets or returns the current DirectAnimation transform

   function Get_DrawingSurface
     (This             : ISGrfxCtl_Type)
     return Pointer_To_IDADrawingSurface;
   --  Sets or returns the current DirectAnimation Drawing Surface

   procedure Put_DrawingSurface
     (This             : ISGrfxCtl_Type;
      ppDrawingSurface : Pointer_To_IDADrawingSurface);
   --  Sets or returns the current DirectAnimation Drawing Surface

   function Get_DrawSurface
     (This             : ISGrfxCtl_Type)
     return Pointer_To_IDADrawingSurface;

   procedure Put_DrawSurface
     (This             : ISGrfxCtl_Type;
      ppDrawingSurface : Pointer_To_IDADrawingSurface);

   function Get_PreserveAspectRatio
     (This      : ISGrfxCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL;
   --  Sets or returns a value indicating if aspect ratio should be preserved
   --  when extents are set

   procedure Put_PreserveAspectRatio
     (This      : ISGrfxCtl_Type;
      fPreserve : GNATCOM.Types.VARIANT_BOOL);
   --  Sets or returns a value indicating if aspect ratio should be preserved
   --  when extents are set

   procedure Clear
     (This : ISGrfxCtl_Type);
   --  Clears the drawing area

   procedure Rotate
     (This        : ISGrfxCtl_Type;
      dblXRot     : Interfaces.C.double;
      dblYRot     : Interfaces.C.double;
      dblZRot     : Interfaces.C.double;
      varReserved : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free        : Boolean := True);
   --  Rotates the coordinate space

   procedure Scale
     (This        : ISGrfxCtl_Type;
      dblXScale   : Interfaces.C.double;
      dblYScale   : Interfaces.C.double;
      dblZScale   : Interfaces.C.double;
      varReserved : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free        : Boolean := True);
   --  Scales the coordinate space

   procedure SetIdentity
     (This : ISGrfxCtl_Type);
   --  Clears any transforms, restoring the control to its initial settings

   procedure Transform4x4
     (This   : ISGrfxCtl_Type;
      matrix : GNATCOM.Types.VARIANT;
      Free   : Boolean := True);
   --  Sets scaling, rotation, and translation information all at once, using a
   --  transform matrix

   procedure Translate
     (This        : ISGrfxCtl_Type;
      dblXOrigin  : Interfaces.C.double;
      dblYOrigin  : Interfaces.C.double;
      dblZOrigin  : Interfaces.C.double;
      varReserved : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free        : Boolean := True);
   --  Sets the X, Y and Z location of the world

end StructuredGraphicControl.ISGrfxCtl_Interface;

