with GNATCOM.Interface;

with GNATCOM.Errors;

package body StructuredGraphicControl.ISpriteCtl_Interface is

   procedure Initialize (This : in out ISpriteCtl_Type) is
   begin
      Set_IID (This, IID_ISpriteCtl);
   end Initialize;

   function Pointer (This : ISpriteCtl_Type)
     return Pointer_To_ISpriteCtl
   is
   begin
      return To_Pointer_To_ISpriteCtl (Address (This));
   end Pointer;

   procedure Attach (This    : in out ISpriteCtl_Type;
                     Pointer : in     Pointer_To_ISpriteCtl)
   is
   begin
      Attach (This, GNATCOM.Interface.To_Pointer_To_IUnknown
              (Pointer.all'Address));
   end Attach;

    function Get_AutoStart
     (This       : ISpriteCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_AutoStart
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_AutoStart;

   procedure Put_AutoStart
     (This       : ISpriteCtl_Type;
      fAutoStart : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_AutoStart
         (Pointer (This),
          fAutoStart));

   end Put_AutoStart;

    function Get_Frame
     (This   : ISpriteCtl_Type)
     return Interfaces.C.unsigned
   is
       RetVal : aliased Interfaces.C.unsigned;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Frame
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Frame;

   procedure Put_Frame
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.unsigned)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Frame
         (Pointer (This),
          iFrame));

   end Put_Frame;

    function Get_FrameMap
     (This     : ISpriteCtl_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_FrameMap
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_FrameMap;

   procedure Put_FrameMap
     (This     : ISpriteCtl_Type;
      FrameMap : GNATCOM.Types.BSTR;
      Free     : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_FrameMap
         (Pointer (This),
          FrameMap));

      if Free then
               GNATCOM.Interface.Free (FrameMap);
      
      end if;

   end Put_FrameMap;

    function Get_InitialFrame
     (This   : ISpriteCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_InitialFrame
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_InitialFrame;

   procedure Put_InitialFrame
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_InitialFrame
         (Pointer (This),
          iFrame));

   end Put_InitialFrame;

    function Get_FinalFrame
     (This   : ISpriteCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_FinalFrame
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_FinalFrame;

   procedure Put_FinalFrame
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_FinalFrame
         (Pointer (This),
          iFrame));

   end Put_FinalFrame;

    function Get_Iterations
     (This    : ISpriteCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Iterations
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Iterations;

   procedure Put_Iterations
     (This    : ISpriteCtl_Type;
      iRepeat : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Iterations
         (Pointer (This),
          iRepeat));

   end Put_Iterations;

    function Get_Library
     (This      : ISpriteCtl_Type)
     return Pointer_To_IDAStatics
   is
       RetVal : aliased Pointer_To_IDAStatics;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Library
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Library;

    function Get_Repeat
     (This    : ISpriteCtl_Type)
     return Interfaces.C.int
   is
       RetVal : aliased Interfaces.C.int;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Repeat
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Repeat;

   procedure Put_Repeat
     (This    : ISpriteCtl_Type;
      iRepeat : Interfaces.C.int)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Repeat
         (Pointer (This),
          iRepeat));

   end Put_Repeat;

    function Get_PlayRate
     (This     : ISpriteCtl_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PlayRate
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PlayRate;

   procedure Put_PlayRate
     (This     : ISpriteCtl_Type;
      dblSpeed : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_PlayRate
         (Pointer (This),
          dblSpeed));

   end Put_PlayRate;

    function Get_Time
     (This     : ISpriteCtl_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Time
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Time;

    function Get_MaximumRate
     (This : ISpriteCtl_Type)
     return Interfaces.C.unsigned
   is
       RetVal : aliased Interfaces.C.unsigned;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_MaximumRate
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_MaximumRate;

   procedure Put_MaximumRate
     (This : ISpriteCtl_Type;
      iFps : Interfaces.C.unsigned)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_MaximumRate
         (Pointer (This),
          iFps));

   end Put_MaximumRate;

    function Get_NumFrames
     (This       : ISpriteCtl_Type)
     return Interfaces.C.unsigned
   is
       RetVal : aliased Interfaces.C.unsigned;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_NumFrames
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_NumFrames;

   procedure Put_NumFrames
     (This       : ISpriteCtl_Type;
      iNumFrames : Interfaces.C.unsigned)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_NumFrames
         (Pointer (This),
          iNumFrames));

   end Put_NumFrames;

    function Get_PlayState
     (This  : ISpriteCtl_Type)
     return PlayStateConstant
   is
       RetVal : aliased PlayStateConstant;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_PlayState
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_PlayState;

    function Get_NumFramesAcross
     (This    : ISpriteCtl_Type)
     return Interfaces.C.unsigned
   is
       RetVal : aliased Interfaces.C.unsigned;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_NumFramesAcross
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_NumFramesAcross;

   procedure Put_NumFramesAcross
     (This    : ISpriteCtl_Type;
      iFrames : Interfaces.C.unsigned)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_NumFramesAcross
         (Pointer (This),
          iFrames));

   end Put_NumFramesAcross;

    function Get_NumFramesDown
     (This    : ISpriteCtl_Type)
     return Interfaces.C.unsigned
   is
       RetVal : aliased Interfaces.C.unsigned;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_NumFramesDown
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_NumFramesDown;

   procedure Put_NumFramesDown
     (This    : ISpriteCtl_Type;
      iFrames : Interfaces.C.unsigned)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_NumFramesDown
         (Pointer (This),
          iFrames));

   end Put_NumFramesDown;

    function Get_UseColorKey
     (This  : ISpriteCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_UseColorKey
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_UseColorKey;

   procedure Put_UseColorKey
     (This  : ISpriteCtl_Type;
      Solid : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_UseColorKey
         (Pointer (This),
          Solid));

   end Put_UseColorKey;

    function Get_Image
     (This   : ISpriteCtl_Type)
     return Pointer_To_IDAImage
   is
       RetVal : aliased Pointer_To_IDAImage;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_Image
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_Image;

   procedure Put_Image
     (This   : ISpriteCtl_Type;
      pImage : Pointer_To_IDAImage)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_Image
         (Pointer (This),
          pImage));

   end Put_Image;

    function Get_ColorKey
     (This      : ISpriteCtl_Type)
     return Pointer_To_IDAColor
   is
       RetVal : aliased Pointer_To_IDAColor;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ColorKey
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ColorKey;

   procedure Put_ColorKey
     (This      : ISpriteCtl_Type;
      pColorKey : Pointer_To_IDAColor)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ColorKey
         (Pointer (This),
          pColorKey));

   end Put_ColorKey;

    function Get_ColorKeyRGB
     (This         : ISpriteCtl_Type)
     return Interfaces.C.unsigned_long
   is
       RetVal : aliased Interfaces.C.unsigned_long;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_ColorKeyRGB
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_ColorKeyRGB;

   procedure Put_ColorKeyRGB
     (This         : ISpriteCtl_Type;
      pColorKeyRGB : Interfaces.C.unsigned_long)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_ColorKeyRGB
         (Pointer (This),
          pColorKeyRGB));

   end Put_ColorKeyRGB;

    function Get_SourceURL
     (This          : ISpriteCtl_Type)
     return GNATCOM.Types.BSTR
   is
       RetVal : aliased GNATCOM.Types.BSTR;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_SourceURL
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_SourceURL;

   procedure Put_SourceURL
     (This          : ISpriteCtl_Type;
      bstrSourceURL : GNATCOM.Types.BSTR;
      Free          : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_SourceURL
         (Pointer (This),
          bstrSourceURL));

      if Free then
               GNATCOM.Interface.Free (bstrSourceURL);
      
      end if;

   end Put_SourceURL;

    function Get_MouseEventsEnabled
     (This    : ISpriteCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL
   is
       RetVal : aliased GNATCOM.Types.VARIANT_BOOL;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_MouseEventsEnabled
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_MouseEventsEnabled;

   procedure Put_MouseEventsEnabled
     (This    : ISpriteCtl_Type;
      Enabled : GNATCOM.Types.VARIANT_BOOL)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_MouseEventsEnabled
         (Pointer (This),
          Enabled));

   end Put_MouseEventsEnabled;

    function Get_TimerInterval
     (This     : ISpriteCtl_Type)
     return Interfaces.C.double
   is
       RetVal : aliased Interfaces.C.double;
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Get_TimerInterval
         (Pointer (This),
          RetVal'Unchecked_Access));

      return RetVal;
   end Get_TimerInterval;

   procedure Put_TimerInterval
     (This     : ISpriteCtl_Type;
      Interval : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Put_TimerInterval
         (Pointer (This),
          Interval));

   end Put_TimerInterval;

   procedure AddFrameMarker
     (This       : ISpriteCtl_Type;
      iFrame     : Interfaces.C.unsigned;
      MarkerName : GNATCOM.Types.BSTR;
      Absolute   : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free       : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddFrameMarker
         (Pointer (This),
          iFrame,
          MarkerName,
          Absolute));

      if Free then
               GNATCOM.Interface.Free (MarkerName);
               GNATCOM.Interface.Free (Absolute);
      
      end if;

   end AddFrameMarker;

   procedure AddTimeMarker
     (This       : ISpriteCtl_Type;
      dblTime    : Interfaces.C.double;
      MarkerName : GNATCOM.Types.BSTR;
      Absolute   : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free       : Boolean := True)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.AddTimeMarker
         (Pointer (This),
          dblTime,
          MarkerName,
          Absolute));

      if Free then
               GNATCOM.Interface.Free (MarkerName);
               GNATCOM.Interface.Free (Absolute);
      
      end if;

   end AddTimeMarker;

   procedure Play
     (This : ISpriteCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Play
         (Pointer (This)));

   end Play;

   procedure Stop
     (This : ISpriteCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Stop
         (Pointer (This)));

   end Stop;

   procedure Pause
     (This : ISpriteCtl_Type)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Pause
         (Pointer (This)));

   end Pause;

   procedure Seek
     (This    : ISpriteCtl_Type;
      dblTime : Interfaces.C.double)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.Seek
         (Pointer (This),
          dblTime));

   end Seek;

   procedure FrameSeek
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.unsigned)
   is
   begin
      GNATCOM.Errors.Error_Check
        (Pointer (This).Vtbl.FrameSeek
         (Pointer (This),
          iFrame));

   end FrameSeek;

end StructuredGraphicControl.ISpriteCtl_Interface;

