with GNATCOM.Dispinterface;

package StructuredGraphicControl.ISpriteCtl_Interface is

   type ISpriteCtl_Type is
     new GNATCOM.Dispinterface.Dispinterface_Type with null record;

   procedure Initialize (This : in out ISpriteCtl_Type);

   function Pointer (This : ISpriteCtl_Type)
     return Pointer_To_ISpriteCtl;

   procedure Attach (This    : in out ISpriteCtl_Type;
                     Pointer : in     Pointer_To_ISpriteCtl);

   function Get_AutoStart
     (This       : ISpriteCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL;
   --  Sets or returns a value indicating whether or not the sprite starts
   --  playback upon loading

   procedure Put_AutoStart
     (This       : ISpriteCtl_Type;
      fAutoStart : GNATCOM.Types.VARIANT_BOOL);
   --  Sets or returns a value indicating whether or not the sprite starts
   --  playback upon loading

   function Get_Frame
     (This   : ISpriteCtl_Type)
     return Interfaces.C.unsigned;
   --  Sets or returns the sprite image frame currently being displayed

   procedure Put_Frame
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.unsigned);
   --  Sets or returns the sprite image frame currently being displayed

   function Get_FrameMap
     (This     : ISpriteCtl_Type)
     return GNATCOM.Types.BSTR;
   --  Sets or returns the order in which frames play back and the length of
   --  time each frame is displayed

   procedure Put_FrameMap
     (This     : ISpriteCtl_Type;
      FrameMap : GNATCOM.Types.BSTR;
      Free     : Boolean := True);
   --  Sets or returns the order in which frames play back and the length of
   --  time each frame is displayed

   function Get_InitialFrame
     (This   : ISpriteCtl_Type)
     return Interfaces.C.int;
   --  Sets or returns the number of the frame that is displayed initially

   procedure Put_InitialFrame
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.int);
   --  Sets or returns the number of the frame that is displayed initially

   function Get_FinalFrame
     (This   : ISpriteCtl_Type)
     return Interfaces.C.int;
   --  Sets or returns the frame to be displayed when playback is stopped

   procedure Put_FinalFrame
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.int);
   --  Sets or returns the frame to be displayed when playback is stopped

   function Get_Iterations
     (This    : ISpriteCtl_Type)
     return Interfaces.C.int;
   --  (Backwards compatible) Please use 'Repeat' property

   procedure Put_Iterations
     (This    : ISpriteCtl_Type;
      iRepeat : Interfaces.C.int);
   --  (Backwards compatible) Please use 'Repeat' property

   function Get_Library
     (This      : ISpriteCtl_Type)
     return Pointer_To_IDAStatics;
   --  Gets the Direct Animation Library

   function Get_Repeat
     (This    : ISpriteCtl_Type)
     return Interfaces.C.int;
   --  Sets or returns the number of times the sprite is to loop during
   --  playback

   procedure Put_Repeat
     (This    : ISpriteCtl_Type;
      iRepeat : Interfaces.C.int);
   --  Sets or returns the number of times the sprite is to loop during
   --  playback

   function Get_PlayRate
     (This     : ISpriteCtl_Type)
     return Interfaces.C.double;
   --  Sets or returns the playback speed of the sprite

   procedure Put_PlayRate
     (This     : ISpriteCtl_Type;
      dblSpeed : Interfaces.C.double);
   --  Sets or returns the playback speed of the sprite

   function Get_Time
     (This     : ISpriteCtl_Type)
     return Interfaces.C.double;
   --  Returns the elapsed playback time of the sprite

   function Get_MaximumRate
     (This : ISpriteCtl_Type)
     return Interfaces.C.unsigned;
   --  Sets or returns the maximum rendering speed of the sprite (number of
   --  times the control will render per second)

   procedure Put_MaximumRate
     (This : ISpriteCtl_Type;
      iFps : Interfaces.C.unsigned);
   --  Sets or returns the maximum rendering speed of the sprite (number of
   --  times the control will render per second)

   function Get_NumFrames
     (This       : ISpriteCtl_Type)
     return Interfaces.C.unsigned;
   --  Sets or returns the number of frames in the Sprite source

   procedure Put_NumFrames
     (This       : ISpriteCtl_Type;
      iNumFrames : Interfaces.C.unsigned);
   --  Sets or returns the number of frames in the Sprite source

   function Get_PlayState
     (This  : ISpriteCtl_Type)
     return PlayStateConstant;
   --  Returns the current playback state of the sprite

   function Get_NumFramesAcross
     (This    : ISpriteCtl_Type)
     return Interfaces.C.unsigned;
   --  Sets or returns the width (in frames) of the sprite source image

   procedure Put_NumFramesAcross
     (This    : ISpriteCtl_Type;
      iFrames : Interfaces.C.unsigned);
   --  Sets or returns the width (in frames) of the sprite source image

   function Get_NumFramesDown
     (This    : ISpriteCtl_Type)
     return Interfaces.C.unsigned;
   --  Sets or returns the height (in frames) of the sprite source image

   procedure Put_NumFramesDown
     (This    : ISpriteCtl_Type;
      iFrames : Interfaces.C.unsigned);
   --  Sets or returns the height (in frames) of the sprite source image

   function Get_UseColorKey
     (This  : ISpriteCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL;
   --  Sets or returns whether or not to use the sprite's transparency
   --  information

   procedure Put_UseColorKey
     (This  : ISpriteCtl_Type;
      Solid : GNATCOM.Types.VARIANT_BOOL);
   --  Sets or returns whether or not to use the sprite's transparency
   --  information

   function Get_Image
     (This   : ISpriteCtl_Type)
     return Pointer_To_IDAImage;
   --  Sets or returns the current DirectAnimation Image

   procedure Put_Image
     (This   : ISpriteCtl_Type;
      pImage : Pointer_To_IDAImage);
   --  Sets or returns the current DirectAnimation Image

   function Get_ColorKey
     (This      : ISpriteCtl_Type)
     return Pointer_To_IDAColor;
   --  Sets or returns the transparency color for a source image

   procedure Put_ColorKey
     (This      : ISpriteCtl_Type;
      pColorKey : Pointer_To_IDAColor);
   --  Sets or returns the transparency color for a source image

   function Get_ColorKeyRGB
     (This         : ISpriteCtl_Type)
     return Interfaces.C.unsigned_long;

   procedure Put_ColorKeyRGB
     (This         : ISpriteCtl_Type;
      pColorKeyRGB : Interfaces.C.unsigned_long);

   function Get_SourceURL
     (This          : ISpriteCtl_Type)
     return GNATCOM.Types.BSTR;
   --  Sets or returns the URL that points to the sprite source image

   procedure Put_SourceURL
     (This          : ISpriteCtl_Type;
      bstrSourceURL : GNATCOM.Types.BSTR;
      Free          : Boolean := True);
   --  Sets or returns the URL that points to the sprite source image

   function Get_MouseEventsEnabled
     (This    : ISpriteCtl_Type)
     return GNATCOM.Types.VARIANT_BOOL;
   --  Enables or disables mouse events

   procedure Put_MouseEventsEnabled
     (This    : ISpriteCtl_Type;
      Enabled : GNATCOM.Types.VARIANT_BOOL);
   --  Enables or disables mouse events

   function Get_TimerInterval
     (This     : ISpriteCtl_Type)
     return Interfaces.C.double;
   --  Sets or returns the interval between sprite frame updates

   procedure Put_TimerInterval
     (This     : ISpriteCtl_Type;
      Interval : Interfaces.C.double);
   --  Sets or returns the interval between sprite frame updates

   procedure AddFrameMarker
     (This       : ISpriteCtl_Type;
      iFrame     : Interfaces.C.unsigned;
      MarkerName : GNATCOM.Types.BSTR;
      Absolute   : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free       : Boolean := True);
   --  Creates a marker that fires an event when playback reaches the
   --  designated frame

   procedure AddTimeMarker
     (This       : ISpriteCtl_Type;
      dblTime    : Interfaces.C.double;
      MarkerName : GNATCOM.Types.BSTR;
      Absolute   : GNATCOM.Types.VARIANT  := GNATCOM.Types.VARIANT_MISSING;
      Free       : Boolean := True);
   --  Creates a marker that fires an event at a specific time

   procedure Play
     (This : ISpriteCtl_Type);
   --  Starts playback of the sprite

   procedure Stop
     (This : ISpriteCtl_Type);
   --  Stops playback and resets the sprite to the beginning

   procedure Pause
     (This : ISpriteCtl_Type);
   --  Stops playback of the sprite and maintains current position

   procedure Seek
     (This    : ISpriteCtl_Type;
      dblTime : Interfaces.C.double);
   --  Sets the sprite playback position to a specific elapsed time

   procedure FrameSeek
     (This   : ISpriteCtl_Type;
      iFrame : Interfaces.C.unsigned);
   --  Sets the sprite playback position to a specific frame

end StructuredGraphicControl.ISpriteCtl_Interface;

